searchData={"content_type":"text/markdown","items":[{"doc":"A high level API interface for creating plots on top of `VegaLite`.\n\nTucan is an Elixir plotting library built on top of `VegaLite`,\ndesigned to simplify the creation of interactive and visually stunning\nplots. With `Tucan`, you can effortlessly generate a wide range of plots,\nfrom simple bar charts to complex composite plots, all while enjoying the\npower and flexibility of a clean composable functional API.\n\nTucan offers a simple API for creating most common plot types similarly\nto the widely used python packages `matplotlib` and `seaborn` without\nrequiring the end user to be familiar with the Vega Lite grammar.","ref":"Tucan.html","title":"Tucan","type":"module"},{"doc":"- **Versatile Plot Types** - Tucan provides an array of plot types, including\nbar charts, line plots, scatter plots, histograms, and more, allowing you to\neffectively represent diverse data sets.\n- **Clean and consistent API** - A clean and consistent plotting API similar\nto `matplotlib` or `seaborn` is provided. You should be able to create most\ncommon plots with a single function call and minimal configuration.\n- **Grouping and Faceting** - Enhance your visualizations with grouping and\nfaceting features, enabling you to examine patterns and trends within subgroups\nof your data.\n- **Customization** - Customize your plots with ease using Tucan's utilities\nfor adjusting plot dimensions, titles, and **themes**.\n- **Thin wrapper on top of VegaLite** - All `VegaLite` functions can be used\nseamlessly with `Tucan` for advanced customizations if needed.\n- **Low level API** - A low level API with helper functions allow you to modify\nany part of a `VegaLite` specification.","ref":"Tucan.html#module-features","title":"Features - Tucan","type":"module"},{"doc":"All supported plots expect as first argument some data, a `VegaLite` specification\nor a binary which is considered a url to some data. Additionally you can use\none of the available `Tucan.Datasets`.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n```\n\nYou can apply semantic grouping by a third variable by modifying the color, the\nshape or the size of the points: \n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\", shape_by: \"species\")\n```\n\nAlternatively you could use the helper grouping functions:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n```\n\n> ##","ref":"Tucan.html#module-basic-usage","title":"Basic usage - Tucan","type":"module"},{"doc":">\n> For some plot types where transformations are applied on the input data it\n> is recommended to use the options instead of the functional API, since in the\n> first case any required grouping will also be applied to the transformations.","ref":"Tucan.html#module-use-the-functional-api-carefully-warning","title":"Use the functional API carefully {: .warning} - Tucan","type":"module"},{"doc":"Tucan also provides some helper functions for generating composite plots.\n`pairplot/3` can be used to plot pairwise relationships across a dataset.\n\n```tucan\nfields = [\"Beak Length (mm)\", \"Beak Depth (mm)\", \"Body Mass (g)\"]\n\nTucan.pairplot(:penguins, fields, diagonal: :density)\n```","ref":"Tucan.html#module-composite-plots","title":"Composite plots - Tucan","type":"module"},{"doc":"Various methods and helper modules allow you to easily modify the style of\na plot.\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\",\n  color_by: \"region\",\n  width: 400,\n  tooltip: :data\n)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n|> Tucan.Grid.set_color(:x, \"red\")\n```\n\nAdditionally `set_theme/2` allows you to set one of the supported `Tucan.Themes`.\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n|> Tucan.set_theme(:latimes)\n```","ref":"Tucan.html#module-customization-themes","title":"Customization & Themes - Tucan","type":"module"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Notice that only a tiny subset of vega-lite configuration\noptions are exported in Tucan's public API. This is more than enough in most\ncases. Additionally, an optional configuration option is added for every\nencoding channel that is used, that allows you to add any vega-lite option\nor change the default options set by Tucan.\n\nFor example:\n\n```tucan\nTucan.bar(:weather, \"date\", \"date\",\n  color_by: \"weather\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :month],\n  y: [aggregate: :count]\n)\n```","ref":"Tucan.html#module-encoding-channels-options","title":"Encoding channels options - Tucan","type":"module"},{"doc":"Returns the specification of an area plot.","ref":"Tucan.html#area/4","title":"Tucan.area/4","type":"function"},{"doc":"* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:line` (`t:boolean/0`) - Whether the line will be included in the chart The default value is `false`.\n* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, areas are stacked \n    * `:normalize` - the stacked charts are normalized\n    * `:streamgraph` - the chart is displaced around a central axis\n    * `:no_stack` - no stacking is applied The default value is `:stacked`.\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:tension` (`t:number/0`) - Depending on the interpolation type, sets the tension parameter\n\n#","ref":"Tucan.html#area/4-options","title":"Options - Tucan.area/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#area/4-data-grouping-options","title":"Data Grouping Options - Tucan.area/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#area/4-styling-options","title":"Styling Options - Tucan.area/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#area/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.area/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#area/4-interactivity-options","title":"Interactivity Options - Tucan.area/4","type":"function"},{"doc":"A simple area chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option: \n\n```tucan\nTucan.area(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou can overlay the points and/or the line:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\", x: [type: :temporal], points: true, line: true)\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nIf you add the `:color_by` property then the area charts are stacked by default. Below\nyou can see how the generic encoding options can be used in order to modify any part\nof the underlying `VegaLite` specification:\n\n```tucan\nTucan.area(:unemployment, \"date\", \"count\",\n  color_by: \"series\",\n  x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n  y: [aggregate: :sum],\n  color: [scale: [scheme: \"category20b\"]],\n  width: 300,\n  height: 200\n)\n```\n\nYou could change the mode to `:normalize` or `:streamgraph`:\n\n```tucan\nleft =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :normalize,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"normalize\")\n\nright =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :streamgraph,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"streamgraph\")\n\nTucan.hconcat([left, right])\n```\n\nOr you could disable the stacking at all:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\",\n  color_by: \"symbol\",\n  mode: :no_stack,\n  x: [type: :temporal],\n  width: 400,\n  fill_opacity: 0.4\n)\n|> Tucan.Scale.set_y_scale(:log)\n```","ref":"Tucan.html#area/4-examples","title":"Examples - Tucan.area/4","type":"function"},{"doc":"Returns the specification of a bar chart.\n\nA bar chart is consisted by a categorical `field` and a numerical `value` field that\ndefines the height of the bars. You can create a grouped bar chart by setting\nthe `:color_by` option.\n\nAdditionally you should specify the aggregate for the `y` values, if your dataset contains\nmore than one values per category.","ref":"Tucan.html#bar/4","title":"Tucan.bar/4","type":"function"},{"doc":"* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, bars are stacked \n    * `:normalize` - the bars are stacked are normalized\n    * `:grouped` - no stacking is applied, a separate bar for each category The default value is `:stacked`.\n\n#","ref":"Tucan.html#bar/4-options","title":"Options - Tucan.bar/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#bar/4-data-grouping-options","title":"Data Grouping Options - Tucan.bar/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#bar/4-styling-options","title":"Styling Options - Tucan.bar/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:x_offset` (`t:keyword/0`) - Extra vega lite options for the `:x_offset` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#bar/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.bar/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#bar/4-interactivity-options","title":"Interactivity Options - Tucan.bar/4","type":"function"},{"doc":"A simple bar chart:\n\n```tucan\ndata = [\n  %{\"a\" => \"A\", \"b\" => 28}, %{\"a\" => \"B\", \"b\" => 55}, %{\"a\" => \"C\", \"b\" => 43},\n  %{\"a\" => \"D\", \"b\" => 91}, %{\"a\" => \"E\", \"b\" => 81}, %{\"a\" => \"F\", \"b\" => 53},\n  %{\"a\" => \"G\", \"b\" => 19}, %{\"a\" => \"H\", \"b\" => 87}, %{\"a\" => \"I\", \"b\" => 52}\n]\n\nTucan.bar(data, \"a\", \"b\")\n```\n\nYou can set a `color_by` option that will create a stacked bar chart:\n\n```tucan\nTucan.bar(:weather, \"date\", \"date\",\n  color_by: \"weather\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :month],\n  y: [aggregate: :count]\n)\n```\n\nIf you set the mode option to `:grouped` you will instead have a different bar\nper group, you can also change the orientation by setting the `:orient` flag.\nSimilarly you can set the mode to `:normalize` in order to have normalized\nstacked bars.\n\n```tucan\ndata = [\n    %{\"category\" => \"A\", \"group\" => \"x\", \"value\" => 0.1},\n    %{\"category\" => \"A\", \"group\" => \"y\", \"value\" => 0.6},\n    %{\"category\" => \"A\", \"group\" => \"z\", \"value\" => 0.9},\n    %{\"category\" => \"B\", \"group\" => \"x\", \"value\" => 0.7},\n    %{\"category\" => \"B\", \"group\" => \"y\", \"value\" => 0.2},\n    %{\"category\" => \"B\", \"group\" => \"z\", \"value\" => 1.1},\n    %{\"category\" => \"C\", \"group\" => \"x\", \"value\" => 0.6},\n    %{\"category\" => \"C\", \"group\" => \"y\", \"value\" => 0.1},\n    %{\"category\" => \"C\", \"group\" => \"z\", \"value\" => 0.2}\n]\n\ngrouped =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :grouped,\n    orient: :vertical\n  )\n\nnormalized =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :normalize\n  )\n\nTucan.hconcat([grouped, normalized])\n```","ref":"Tucan.html#bar/4-examples","title":"Examples - Tucan.bar/4","type":"function"},{"doc":"Returns the specification of a box plot.\n\nBy default a one dimensional box plot of the `:field` - which must be a numerical variable - is\ngenerated. You can add a second dimension across a categorical variable by either setting the\n`:group` or `:color_by` options.\n\nBy default a Tukey box plot will be generated. In the Tukey box plot the whisker spans from\nthe smallest data to the largest data within the range `[Q1 - k * IQR, Q3 + k * IQR]` where\n`Q1`and `Q3` are the first and third quartiles while `IQR` is the interquartile range\n`(Q3-Q1)`. You can specify if needed the constant `k` which defaults to 1.5.\n\nAdditionally you can set the `mode` to `:min_max`  where the lower and upper whiskers are\ndefined as the min and max respectively. No points will be considered as outliers for this\ntype of box plots. In this case the `k` value is ignored.\n\n> ##","ref":"Tucan.html#boxplot/3","title":"Tucan.boxplot/3","type":"function"},{"doc":">\n> A box plot (box and whisker plot) displays the five-number summary of a set of data. The\n> five-number summary is the minimum, first quartile, median, third quartile, and maximum.\n> In a box plot, we draw a box from the first quartile to the third quartile. A vertical\n> line goes through the box at the median.","ref":"Tucan.html#boxplot/3-what-is-a-box-plot-info","title":"What is a box plot {: .info} - Tucan.boxplot/3","type":"function"},{"doc":"* `:k` (`t:float/0`) - The constant used for calculating the extent of the whiskers in a Tukey boxplot. Applicable\n  only if `:mode` is set to `:tukey`. The default value is `1.5`.\n* `:mode` - The type of the box plot. Either a Tukey box plot will be created or a min-max plot. The default value is `:tukey`.\n\n#","ref":"Tucan.html#boxplot/3-options","title":"Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A field to be used for grouping the boxplot. It is used for adding a second dimension to\n  the plot. If not set the plot will be one dimensional. Notice that a grouping is automatically\n  applied if the `:color_by` option is set.\n\n#","ref":"Tucan.html#boxplot/3-data-grouping-options","title":"Data Grouping Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#boxplot/3-styling-options","title":"Styling Options - Tucan.boxplot/3","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#boxplot/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.boxplot/3","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#boxplot/3-interactivity-options","title":"Interactivity Options - Tucan.boxplot/3","type":"function"},{"doc":"A one dimensional Tukey boxplot: \n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\")\n```\n\nYou can set `:group` or `:color_by` in order to set a second dimension:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\n```\n\nYou can set the mode to `:min_max` in order to extend the whiskers to the min and max values:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", mode: :min_max)\n```\n\nBy setting the `:orient` to `:vertical` you can change the default horizontal orientation:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", orient: :vertical)\n```","ref":"Tucan.html#boxplot/3-examples","title":"Examples - Tucan.boxplot/3","type":"function"},{"doc":"Returns the specification of a bubble plot.\n\nA bubble plot is a scatter plot with a third parameter defining the size of the dots.\n\nAll `x`, `y` and `size` must be numerical data fields.\n\nSee also `scatter/4`.","ref":"Tucan.html#bubble/5","title":"Tucan.bubble/5","type":"function"},{"doc":"#","ref":"Tucan.html#bubble/5-options","title":"Options - Tucan.bubble/5","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#bubble/5-data-grouping-options","title":"Data Grouping Options - Tucan.bubble/5","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#bubble/5-styling-options","title":"Styling Options - Tucan.bubble/5","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#bubble/5-encodings-custom-options","title":"Encodings Custom Options - Tucan.bubble/5","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#bubble/5-interactivity-options","title":"Interactivity Options - Tucan.bubble/5","type":"function"},{"doc":"```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", width: 400)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nYou could use a fourth variable to color the graph. As always you can set the `tooltip` in\norder to make the plot interactive:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nIt makes more sense to use a log scale for the _x axis_:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n```","ref":"Tucan.html#bubble/5-examples","title":"Examples - Tucan.bubble/5","type":"function"},{"doc":"Adds a `color` encoding for the given field.","ref":"Tucan.html#color_by/3","title":"Tucan.color_by/3","type":"function"},{"doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#color_by/3-options","title":"Options - Tucan.color_by/3","type":"function"},{"doc":"Concatenates the given plots.\n\nThis corresponds to the general concatenation of vega-lite (wrappable).","ref":"Tucan.html#concat/2","title":"Tucan.concat/2","type":"function"},{"doc":"Plot the counts of observations for a categorical variable.\n\nTakes a categorical `field` as input and generates a count plot\nvisualization. By default the counts are plotted on the *y-axis*\nand the categorical `field` across the *x-axis*.\n\nThis is similar to `histogram/3` but specifically for a categorical\nvariable.\n\nThis is a simple wrapper around `bar/4` where by default the count of\nobservations is mapped to the `y` variable.\n\n> ##","ref":"Tucan.html#countplot/3","title":"Tucan.countplot/3","type":"function"},{"doc":"> \n> A countplot is a type of bar chart used in data visualization to\n> display the **frequency of occurrences of categorical data**. It is\n> particularly useful for visualizing the *distribution* and *frequency*\n> of different categories within a dataset.\n>\n> In a countplot, each unique category is represented by a bar, and the\n> height of the bar corresponds to the number of occurrences of that\n> category in the data.","ref":"Tucan.html#countplot/3-what-is-a-countplot-tip","title":"What is a countplot? {: .tip} - Tucan.countplot/3","type":"function"},{"doc":"See `bar/4`","ref":"Tucan.html#countplot/3-options","title":"Options - Tucan.countplot/3","type":"function"},{"doc":"We will use the `:titanic` dataset on the following examples. We can\nplot the number of passengers by ticket class:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\")\n```\n\nYou can make the bars horizontal by setting the `:orient` option:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", orient: :vertical)\n```\n\nYou can set `:color_by` to group it by a second variable:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\")\n```\n\nBy default the bars are stacked. You can unstack them by setting the\n`:mode` to `:grouped`\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\", mode: :grouped)\n```","ref":"Tucan.html#countplot/3-examples","title":"Examples - Tucan.countplot/3","type":"function"},{"doc":"Plot the distribution of a numeric variable.\n\nDensity plots allow you to visualize the distribution of a numeric variable for one\nor several groups. If you want to draw the density for several groups you need to\nspecify the `:color_by` option which is assumed to be a categorical variable.\n\n> #","ref":"Tucan.html#density/3","title":"Tucan.density/3","type":"function"},{"doc":">\n> Since the grouping variable must also be used for properly calculating the density\n> transformation you **should avoid calling the `color_by/3` grouping function** after\n> a `density/3` call. Instead use the `:color_by` option, which will ensure that the\n> proper settings are applied to the underlying transformation.\n>\n> Calling `color_by/3` would produce this graph:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\")\n> |> Tucan.color_by(\"Species\")\n> ```\n>\n> In the above case the density function has been calculated on the complete dataset\n> and you cannot color by the `Species`. Instead you should use the `:color_by`\n> option which would calculate the density function per group:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n> ```\n>\n> Alternatively you should use the `:groupby` option in order to group the density\n> transform by the `Species` field and then apply the `color_by/3` function:\n>\n> ```elixir\n> Tucan.density(:penguins, \"Body Mass (g)\", groupby: [\"Species\"], fill_opacity: 0.2)\n> |> Tucan.color_by(\"Species\")\n> ```\n\nSee also `histogram/3`.","ref":"Tucan.html#density/3-avoid-calling-color_by-3-with-a-density-plot-warning","title":"Avoid calling `color_by/3` with a density plot {: .warning} - Tucan.density/3","type":"function"},{"doc":"* `:bandwidth` (`t:float/0`) - The bandwidth (standard deviation) of the Gaussian kernel. If unspecified or set to\n  zero, the bandwidth value is automatically estimated from the input data using\n  Scott’s rule.\n* `:counts` (`t:boolean/0`) - A boolean flag indicating if the output values should be probability estimates\n  (false) or smoothed counts (true). The default value is `false`.\n* `:cumulative` (`t:boolean/0`) - A boolean flag indicating whether to produce density estimates (false) or cumulative\n  density estimates (true). The default value is `false`.\n* `:extent` - A `[min, max]` domain from which to sample the distribution. If unspecified, the extent\n  will be determined by the observed minimum and maximum values of the density value field.\n* `:groupby` (list of `t:String.t/0`) - The data fields to group by. If not specified, a single group containing all data\n  objects will be used. This is applied only on the density transform.\n\n  In most cases you only need to set `color_by` which will automatically handle the\n  density transform grouping. Use `groupby` only if you want to manually post-process\n  the generated specification, or if you want to apply grouping by more than one\n  variable.\n\n  If both `groupby` and `color_by` are set then only `groupby` is used for grouping\n  the density transform and `color_by` is used for encoding the color.\n* `:maxsteps` (`t:integer/0`) - The maximum number of samples to take along the extent domain for plotting the density. The default value is `200`.\n* `:minsteps` (`t:integer/0`) - The minimum number of samples to take along the extent domain for plotting the density. The default value is `25`.\n* `:steps` (`t:integer/0`) - The exact number of samples to take along the extent domain for plotting the density. If\n  specified, overrides both minsteps and maxsteps to set an exact number of uniform samples.\n  Potentially useful in conjunction with a fixed extent to ensure consistent sample points\n  for stacked densities.\n\n#","ref":"Tucan.html#density/3-options","title":"Options - Tucan.density/3","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#density/3-data-grouping-options","title":"Data Grouping Options - Tucan.density/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#density/3-styling-options","title":"Styling Options - Tucan.density/3","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#density/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.density/3","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#density/3-interactivity-options","title":"Interactivity Options - Tucan.density/3","type":"function"},{"doc":"```tucan\nTucan.density(:penguins, \"Body Mass (g)\")\n```\n\nIt is a common use case to compare the density of several groups in a dataset. Several\noptions exist to do so. You can plot all items on the same chart, using transparency and\nannotation to make the comparison possible.\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.5)\n```\n\nYou can also combine it with `facet_by/4` in order to draw a different plot for each value\nof the grouping variable. Notice that we need to set the `:groupby` variable in order\nto correctly calculate the density plot per field's value.\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", groupby: [\"Species\"])\n|> Tucan.color_by(\"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```\n\nYou can control the smoothing by setting a specific `bandwidth` value (if not set it is\nautomatically calculated by vega lite):\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", bandwidth: 20.0, fill_opacity: 0.5)\n```\n\nYou can plot a cumulative density distribution by setting the `:cumulative` option to `true`:\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true)\n```\n\nor calculate a separate cumulative distribution for each group: \n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true, color_by: \"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```","ref":"Tucan.html#density/3-examples","title":"Examples - Tucan.density/3","type":"function"},{"doc":"Draws a density heatmap.\n\nA density heatmap is a bivariate histogram, e.g. the `x`, `y` data are binned\nwithin rectangles that tile the plot and then the count of observations within\neach rectangle is shown with the fill color.\n\nBy default the `count` of observations within each rectangle is encoded, but you\ncan calculate the statistic of any field and use it instead. \n\nDensity heatmaps are a powerful visualization tool that find their best use cases\nin situations where you need to explore and understand the distribution and\nconcentration of data points in a two-dimensional space. They are particularly\neffective when dealing with large datasets, allowing you to uncover patterns,\nclusters, and trends that might be difficult to discern in raw data.","ref":"Tucan.html#density_heatmap/4","title":"Tucan.density_heatmap/4","type":"function"},{"doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a bin. The\n  `z` field must be set if `aggregate` is set.\n* `:z` (`t:String.t/0`) - If set corresponds to the field that will be used for calculating the color fo the\n  bin using the provided aggregate. If not set (the default behaviour) the count of\n  observations are used for coloring the bin.\n\n#","ref":"Tucan.html#density_heatmap/4-options","title":"Options - Tucan.density_heatmap/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#density_heatmap/4-styling-options","title":"Styling Options - Tucan.density_heatmap/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#density_heatmap/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.density_heatmap/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#density_heatmap/4-interactivity-options","title":"Interactivity Options - Tucan.density_heatmap/4","type":"function"},{"doc":"Let's start with a default density heatmap on the penguins dataset:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n```\n\nYou can summarize over another field:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\", z: \"Body Mass (g)\", aggregate: :mean)\n```","ref":"Tucan.html#density_heatmap/4-examples","title":"Examples - Tucan.density_heatmap/4","type":"function"},{"doc":"Draw a donut chart.\n\nA donut chart is a circular visualization that resembles a pie chart but\nfeatures a hole at its center. This central hole creates a _donut_ shape,\ndistinguishing it from traditional pie charts. \n\nThis is a wrapper around `pie/4` that sets by default the `:inner_radius`.","ref":"Tucan.html#donut/4","title":"Tucan.donut/4","type":"function"},{"doc":"See `pie/4`","ref":"Tucan.html#donut/4-options","title":"Options - Tucan.donut/4","type":"function"},{"doc":"```tucan\nTucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#donut/4-examples","title":"Examples - Tucan.donut/4","type":"function"},{"doc":"Apply facetting on the input plot `vl` by the given `field`.\n\nThis will create multiple plots either horizontally (`:column` faceting mode),\nvertically (`:row` faceting mode) or arbitrarily (`:wrapped` mode). One plot will\nbe created for each distinct value of the given `field`, which must be a\ncategorical variable.\n\nIn the case of `:wrapped` a `:columns` option should also be provided which\nwill determine the number of columns of the composite plot.\n\n`opts` is an arbitrary keyword list that will be passed to the `:row` or `:column`\nencoding.\n\n> ##","ref":"Tucan.html#facet_by/4","title":"Tucan.facet_by/4","type":"function"},{"doc":">\n> Facet plots, also known as trellis plots or small multiples, are figures made up\n> of multiple subplots which have the same set of axes, where each subplot shows\n> a subset of the data.","ref":"Tucan.html#facet_by/4-facet-plots-info","title":"Facet plots {: .info} - Tucan.facet_by/4","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.facet_by(:column, \"species\")\n|> Tucan.color_by(\"species\")\n```\n\nWith `:wrapped` mode and custom sorting:\n\n```tucan\nTucan.density(:movies, \"IMDB Rating\", color_by: \"Major Genre\")\n|> Tucan.facet_by(:wrapped, \"Major Genre\", columns: 4, sort: [op: :mean, field: \"IMDB Rating\"])\n|> Tucan.Legend.set_enabled(:color, false)\n|> Tucan.set_title(\"Density of IMDB rating by Genre\", offset: 20)\n```","ref":"Tucan.html#facet_by/4-examples","title":"Examples - Tucan.facet_by/4","type":"function"},{"doc":"Adds a `fill` encoding for the given field.","ref":"Tucan.html#fill_by/3","title":"Tucan.fill_by/3","type":"function"},{"doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#fill_by/3-options","title":"Options - Tucan.fill_by/3","type":"function"},{"doc":"Flips the axes of the provided chart.\n\nThis works for both one dimensional and two dimensional charts. All positional channels\nthat are defined will be flipped.\n\nThis is used internally by plots that support setting orientation.","ref":"Tucan.html#flip_axes/1","title":"Tucan.flip_axes/1","type":"function"},{"doc":"Concatenates horizontally the given plots.","ref":"Tucan.html#hconcat/2","title":"Tucan.hconcat/2","type":"function"},{"doc":"Returns the specification of a heatmap.\n\nA heatmap is a graphical representation of data where the individual values\ncontained in a matrix are represented as colors.\n\nIt expects two categorical fields `x`, `y` which will be used for the axes\nand a numerical field `color`. If `color` is `nil` then the color represents\nthe count of the observations for each `x, y`.\n\nIf an `:aggregate` is set this statistic will be used for encoding the color.\nIf no `:aggregate` is set the color encodes by default the `:mean` of the\ndata.","ref":"Tucan.html#heatmap/5","title":"Tucan.heatmap/5","type":"function"},{"doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a heatmap\n  tile. Defaults to `:mean` which in case of single data will encode the value of\n  the `color` data field.\n\n  Ignored if `:color` is set to `nil`.\n* `:annotate` (`t:boolean/0`) - If set to `true` then the values of each cell will be included in the plot. The default value is `false`.\n\n#","ref":"Tucan.html#heatmap/5-options","title":"Options - Tucan.heatmap/5","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:color_scheme` (`t:atom/0`) - The colorscheme to use, for supported colorschemes check `Tucan.Scale`. Notice that\n  this is just a helper option for easily setting color schemes. If you need to set\n  specific colors or customize the scheme, use `Tucan.Scale.set_color_scheme/3`.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#heatmap/5-styling-options","title":"Styling Options - Tucan.heatmap/5","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:text` (`t:keyword/0`) - Extra vega lite options for the `:text` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#heatmap/5-encodings-custom-options","title":"Encodings Custom Options - Tucan.heatmap/5","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#heatmap/5-interactivity-options","title":"Interactivity Options - Tucan.heatmap/5","type":"function"},{"doc":"A simple heatmap of two categorical variables, using a third one for the\ncolor values.\n\n```tucan\ndata = [\n  %{\"x\" => \"A\", \"y\" => \"K\", \"value\" => 0.5},\n  %{\"x\" => \"A\", \"y\" => \"L\", \"value\" => 1.5},\n  %{\"x\" => \"A\", \"y\" => \"M\", \"value\" => 4.5},\n  %{\"x\" => \"B\", \"y\" => \"K\", \"value\" => 1.5},\n  %{\"x\" => \"B\", \"y\" => \"L\", \"value\" => 2.5},\n  %{\"x\" => \"B\", \"y\" => \"M\", \"value\" => 0.5},\n  %{\"x\" => \"C\", \"y\" => \"K\", \"value\" => -1.5},\n  %{\"x\" => \"C\", \"y\" => \"L\", \"value\" => 5.5},\n  %{\"x\" => \"C\", \"y\" => \"M\", \"value\" => 1.5},\n]\n\nTucan.heatmap(data, \"x\", \"y\", \"value\", width: 200, height: 200)\n```\n\nYou can change the color scheme:\n\n```tucan\nTucan.heatmap(:glue, \"Task\", \"Model\", \"Score\", color_scheme: :redyellowgreen, tooltip: true)\n```\n\nHeatmaps are also useful for visualizing temporal data. Let's use a heatmap to examine\nhow Seattle's max temperature changes over the year. On the _x-axis_ we will encode the\ndays of the month along the x-axis, and the months on the _y-axis_. We will aggregate\nover the max temperature for the color field. (example borrowed from\n[here](https://observablehq.com/@jonfroehlich/basic-time-series-plots-in-vega-lite?collection=@jonfroehlich/intro-to-vega-lite))\n\n```tucan\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month],\n  tooltip: true\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n```\n\nYou can enable annotations by setting the `:annotate` flag:\n\n```tucan\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  annotate: true,\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month],\n  text: [format: \".1f\"],\n  tooltip: true,\n  width: 800\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n```","ref":"Tucan.html#heatmap/5-examples","title":"Examples - Tucan.heatmap/5","type":"function"},{"doc":"Plots a histogram.\n\nSee also `density/3`","ref":"Tucan.html#histogram/3","title":"Tucan.histogram/3","type":"function"},{"doc":"* `:extent` - A two-element (`[min, max]`) array indicating the range of desired bin values.\n* `:maxbins` (`t:integer/0`) - Maximum number of bins.\n* `:orient` - Histogram's orientation. It specifies the axis along which the field values\n  are plotted. The default value is `:horizontal`.\n* `:relative` (`t:boolean/0`) - If set a relative frequency histogram is generated. The default value is `false`.\n* `:stacked` (`t:boolean/0`) - If set it will stack the group histograms instead of layering one over another. Valid\n  only if a semantic grouping has been applied.\n* `:step` - An exact step size to use between bins. If provided, options such as `maxbins`\n  will be ignored.\n\n#","ref":"Tucan.html#histogram/3-options","title":"Options - Tucan.histogram/3","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - The field to group observations by. This will used for coloring the histogram\n  if set.\n\n#","ref":"Tucan.html#histogram/3-data-grouping-options","title":"Data Grouping Options - Tucan.histogram/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#histogram/3-styling-options","title":"Styling Options - Tucan.histogram/3","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:x2` (`t:keyword/0`) - Extra vega lite options for the `:x2` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#histogram/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.histogram/3","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#histogram/3-interactivity-options","title":"Interactivity Options - Tucan.histogram/3","type":"function"},{"doc":"Histogram of `Horsepower`\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\")\n```\n\nYou can flip the plot by setting the `:orient` option to `:vertical`:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", orient: :vertical)\n```\n\nBy setting the `:relative` flag you can get a relative frequency histogram:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", relative: true)\n```\n\nYou can increase the number of bins by settings the `maxbins` or the `step` options:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", step: 5)\n```\n\nYou can draw multiple histograms by grouping the observations by a second\n*categorical* variable:\n\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n```\n\nBy default the histograms are plotted layered, but you can also stack them:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5, stacked: true)\n```\n\nor you can facet it, in order to make the histograms more clear:\n\n```tucan\nhistograms =\n  Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", tooltip: true)\n  |> Tucan.facet_by(:column, \"Origin\")\n\nrelative_histograms =\n  Tucan.histogram(:cars, \"Horsepower\", relative: true, color_by: \"Origin\", tooltip: true)\n  |> Tucan.facet_by(:column, \"Origin\")\n\nTucan.vconcat([histograms, relative_histograms])\n```","ref":"Tucan.html#histogram/3-examples","title":"Examples - Tucan.histogram/3","type":"function"},{"doc":"Adds a horizontal line at the given `h` position.\n\nFor supported options check `line/4`.","ref":"Tucan.html#hruler/3","title":"Tucan.hruler/3","type":"function"},{"doc":"Returns the specification of a jointplot.\n\nA jointplot is a plot of two numerical variables along with marginal univariate\ngraphs. If no options are set the joint is a scatter plot and the marginal are\nthe histograms of the two variables.\n\n> ##","ref":"Tucan.html#jointplot/4","title":"Tucan.jointplot/4","type":"function"},{"doc":">\n> By default a jointplot will have a square shape, e.g. it will have the same\n> width and height. The `:width` option affects the width of the central (joint)\n> plot.\n>\n> For the marginal distributions you can the `:ratio` option which specifies\n> the ratio of joint axes height to marginal axes height.","ref":"Tucan.html#jointplot/4-marginal-plots-dimensions-info","title":"Marginal plots dimensions {: .info} - Tucan.jointplot/4","type":"function"},{"doc":"* `:joint` - The plot type to be used for the main (joint) plot. Can be one of\n  `:scatter` and `:density_heatmap`. The default value is `:scatter`.\n* `:joint_opts` (`t:keyword/0`) - Arbitrary options list for the joint plot. The supported options\n  depend on the selected `:joint` type. The default value is `[]`.\n* `:marginal` - The plot type to be used for the marginal plots. Can be one of\n  `:histogram` and `:density`. The default value is `:histogram`.\n* `:marginal_opts` (`t:keyword/0`) - Arbitrary options list for the marginal plots. The supported options\n  depend on the selected `:marginal` type. The default value is `[]`.\n* `:ratio` (`t:float/0`) - The ratio of the marginal plots secondary dimension with respect to\n  the joint plot dimension. The default value is `0.45`.\n\n#","ref":"Tucan.html#jointplot/4-options","title":"Options - Tucan.jointplot/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#jointplot/4-data-grouping-options","title":"Data Grouping Options - Tucan.jointplot/4","type":"function"},{"doc":"* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:spacing` (`t:pos_integer/0`) - The spacing between the marginals and the joint plot. The default value is `15`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - The dimension of the central (joint) plot. The same value is used for\n  both the width and height of the plot. The default value is `200`.","ref":"Tucan.html#jointplot/4-styling-options","title":"Styling Options - Tucan.jointplot/4","type":"function"},{"doc":"A simple joint plot between two variables.\n\n```tucan\nTucan.jointplot(:iris, \"petal_width\", \"petal_length\", width: 200)\n```\n\nYou can also pass `:color_by` to apply a semantic grouping. If set it will be\napplied both to the joint and the marginal plots.\n\n```tucan\nTucan.jointplot(\n  :iris, \"petal_width\", \"petal_length\",\n  color_by: \"species\",\n  fill_opacity: 0.5,\n  width: 200\n)\n```\n\nYou can change the type of the join plot and the marginal distributions:\n\n```tucan\nTucan.jointplot(\n  :penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\",\n  joint: :density_heatmap,\n  marginal: :density,\n  ratio: 0.3\n)\n```","ref":"Tucan.html#jointplot/4-examples","title":"Examples - Tucan.jointplot/4","type":"function"},{"doc":"Creates a layered plot.\n\nThis is a simple wrapper around `VegaLite.layers/2` which by default adds\nthe layers under an empty plot.","ref":"Tucan.html#layers/2","title":"Tucan.layers/2","type":"function"},{"doc":"Draw a line plot between `x` and `y`\n\nBoth `x` and `y` are considered numerical variables.","ref":"Tucan.html#lineplot/4","title":"Tucan.lineplot/4","type":"function"},{"doc":"* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:tension` (`t:number/0`) - Depending on the interpolation type, sets the tension parameter\n\n#","ref":"Tucan.html#lineplot/4-options","title":"Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A field to group by the lines without affecting the style of it.\n\n#","ref":"Tucan.html#lineplot/4-data-grouping-options","title":"Data Grouping Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:filled` (`t:boolean/0`) - Whether the points will be filled or not. Valid only if `:points` is set. The default value is `true`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#lineplot/4-styling-options","title":"Styling Options - Tucan.lineplot/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#lineplot/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.lineplot/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#lineplot/4-interactivity-options","title":"Interactivity Options - Tucan.lineplot/4","type":"function"},{"doc":"Plotting a simple line chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option: \n\n```tucan\nTucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou could plot all stocks of the dataset with different colors by setting the `:color_by`\noption. If you do not want to color lines differently, you can pass the `:group_by` option\ninstead of `:color_by`:\n\n```tucan\nleft = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], color_by: \"symbol\")\nright = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], group_by: \"symbol\")\n\nTucan.hconcat([left, right])\n```\n\nYou can also overlay the points by setting the `:points` and `:filled` opts. Notice\nthat below we plot by year and aggregating the `y` values:\n\n```tucan\nfilled_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    tooltip: true,\n    width: 300\n  )\n\nstroked_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    filled: false,\n    tooltip: true,\n    width: 300\n  )\n\nTucan.hconcat([filled_points, stroked_points])\n```\n\nYou can use various interpolation methods. Some examples follow:\n\n```tucan\nplots = \n  for interpolation   Tucan.set_title(interpolation)\n  end\n\nVegaLite.new(columns: 2)\n|> Tucan.concat(plots)\n```","ref":"Tucan.html#lineplot/4-examples","title":"Examples - Tucan.lineplot/4","type":"function"},{"doc":"Creates if needed a `VegaLite` plot and adds data to it.\n\nThe behaviour of this function depends on the type of `plotdata`:\n\n* if a `VegaLite.t()` struct is passed then it is returned unchanged.\n* If it is a binary it is considered a url and the `VegaLite.data_from_url/2` is\n  called on a newly created `VegaLite` struct.\n* if it is an atom then it is considered a `Tucan.Dataset` and it is translated to\n  the dataset's url. If the dataset name is invalid an exception is raised.\n* in any other case it is considered a set of data values and the values are set\n  as data to a newly created `VegaLite` struct.","ref":"Tucan.html#new/2","title":"Tucan.new/2","type":"function"},{"doc":"Plot pairwise relationships in a dataset.\n\nThis function expects an array of fields to be provided. A grid will be created\nwhere each numeric variable in `fields` will be shared across the y-axes across\na single row and the x-axes across a single column.\n\n> ##","ref":"Tucan.html#pairplot/3","title":"Tucan.pairplot/3","type":"function"},{"doc":">\n> Notice that currently `pairplot/3` works only with numerical (`:quantitative`)\n> variables. If you need to create a pair plot containing other variable types\n> you need to manually build the grid using the `VegaLite` concatenation operations.","ref":"Tucan.html#pairplot/3-numerical-field-types-warning","title":"Numerical field types {: .warning} - Tucan.pairplot/3","type":"function"},{"doc":"* `:diagonal` - The plot type to be used for the diagonal subplots. Can be one on\n  `:scatter`, `:density` and `:histogram`. The default value is `:scatter`.\n* `:plot_fn` (function of arity 3) - An optional function for customizing the look any subplot. It expects a\n  function with the following signature:\n\n  ```elixir\n  (vl :: VegaLite.t(), row :: {binary(), integer()}, column :: {binary(), integer()})\n    :: VegaLite.t() \n  ```\n\n  where both `row` and `column` are tuples containing the index and field of\n  the current and row and column respectively.\n\n  You are free to specify any function for every cell of the grid.\n\n#","ref":"Tucan.html#pairplot/3-options","title":"Options - Tucan.pairplot/3","type":"function"},{"doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\nNotice that if set `width` and `height` will be applied to individual sub plots. On\nthe other hand `title` is applied to the composite plot.","ref":"Tucan.html#pairplot/3-styling-options","title":"Styling Options - Tucan.pairplot/3","type":"function"},{"doc":"By default a scatter plot will be drawn for all pairwise plots:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n```\n\nYou can color the points by another field in to add some semantic mapping. Notice\nthat you need the `recursive` option to `true` for the grouping to be applied on all\ninternal subplots.\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nBy specifying the `:diagonal` option you can change the default plot for the diagonal\nelements to a histogram:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130, diagonal: :histogram)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nAdditionally you have the option to configure a `plot_fn` with which we can go crazy and\nmodify any part of the grid based on our needs. `plot_fn` should accept as input a `VegaLite`\nstruct and two tuples containing the row and column fields and indexes. In the following\nexample we draw differently the diagonal, the lower and the upper grid. Notice that we don't\ncall `color_by/3` since we color differently the plots based on their index positions.\n\n```tucan\nTucan.pairplot(:iris, [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"],\n  width: 150,\n  height: 150,\n  plot_fn: fn vl, {row_field, row_index}, {col_field, col_index} ->\n    cond do\n      # For the first two diagonal elements we plot a histogram, no \n      row_index == col_index and row_index  \n        Tucan.histogram(vl, row_field)\n\n      row_index == 2 and col_index == 2 ->\n        Tucan.stripplot(vl, row_field, group: \"species\", style: :tick)\n        |> Tucan.color_by(\"species\") \n        |> Tucan.Axes.put_options(:y, labels: false)  \n\n      # For the other diagonal plots we plot a histogram colored_by the species\n      row_index == col_index ->\n        Tucan.histogram(vl, row_field, color_by: \"species\")\n\n      # For the upper part of the diagram we apply a scatter plot\n      row_index  \n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.color_by(\"species\")\n\n      # for anything else scatter plot with a quantitative color scale\n      # and size\n      true ->\n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.size_by(\"petal_width\", type: :quantitative)\n        \n    end\n  end\n)\n```","ref":"Tucan.html#pairplot/3-examples","title":"Examples - Tucan.pairplot/3","type":"function"},{"doc":"Draws a pie chart.\n\nA pie chart is a circle divided into sectors that each represents a proportion\nof the whole. The `field` specifies the data column that contains the proportions\nof each category. The chart will be colored by the `category` field.\n\n> ##","ref":"Tucan.html#pie/4","title":"Tucan.pie/4","type":"function"},{"doc":">\n> Despite it's popularity pie charts should rarely be used. Pie charts are best\n> suited for displaying a small number of categories and can make it challenging\n> to accurately compare data. They rely on angle perception, which can lead to\n> misinterpretation, and lack the precision offered by other charts like bar\n> charts or line charts.\n>\n> Instead, opt for alternatives such as bar charts for straightforward comparisons,\n> stacked area charts for cumulative effects.\n> \n> The following example showcases the limitations of a pie chart, compared to a\n> bar chart:\n>\n> ```tucan\n> alias VegaLite, as: Vl\n>\n> data = [\n>   %{value: 30, category: \"A\"},\n>   %{value: 33, category: \"B\"},\n>   %{value: 38, category: \"C\"}\n> ]\n> \n> pie = Tucan.pie(data, \"value\", \"category\")\n> bar = Tucan.bar(data, \"category\", \"value\", orient: :vertical)\n>\n> Tucan.hconcat([pie, bar])\n> |> Tucan.set_title(\"Pie vs Bar chart\", anchor: :middle, offset: 15)\n> ```","ref":"Tucan.html#pie/4-avoid-using-pie-charts-warning","title":"Avoid using pie charts {: .warning} - Tucan.pie/4","type":"function"},{"doc":"* `:aggregate` (`t:atom/0`) - The statistic to use (if any) for aggregating values per pie slice (e.g. `:mean`).\n* `:inner_radius` (`t:integer/0`) - The inner radius in pixels. `0` for a pie chart, `> 0` for a donut chart. If not\n  set it defaults to 0\n\n#","ref":"Tucan.html#pie/4-options","title":"Options - Tucan.pie/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#pie/4-styling-options","title":"Styling Options - Tucan.pie/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:theta` (`t:keyword/0`) - Extra vega lite options for the `:theta` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#pie/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.pie/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#pie/4-interactivity-options","title":"Interactivity Options - Tucan.pie/4","type":"function"},{"doc":"```tucan\nTucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#pie/4-examples","title":"Examples - Tucan.pie/4","type":"function"},{"doc":"Returns the specification of a punch card plot.\n\nA punch card plot is similar to a heatmap but instead of color the third\ndimension is encoded by the size of bubbles.\n\nSee also `heatmap/5`.","ref":"Tucan.html#punchcard/5","title":"Tucan.punchcard/5","type":"function"},{"doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a heatmap\n  tile. Defaults to `:mean` which in case of single data will encode the value of\n  the `color` data field.\n\n  Ignored if `:color` is set to `nil`.\n* `:annotate` (`t:boolean/0`) - If set to `true` then the values of each cell will be included in the plot. The default value is `false`.\n\n#","ref":"Tucan.html#punchcard/5-options","title":"Options - Tucan.punchcard/5","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:color_scheme` (`t:atom/0`) - The colorscheme to use, for supported colorschemes check `Tucan.Scale`. Notice that\n  this is just a helper option for easily setting color schemes. If you need to set\n  specific colors or customize the scheme, use `Tucan.Scale.set_color_scheme/3`.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#punchcard/5-styling-options","title":"Styling Options - Tucan.punchcard/5","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#punchcard/5-encodings-custom-options","title":"Encodings Custom Options - Tucan.punchcard/5","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#punchcard/5-interactivity-options","title":"Interactivity Options - Tucan.punchcard/5","type":"function"},{"doc":"```tucan\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.set_title(\"Punch card of Avg Max Temperatures in Seattle (2012-2015)\")\n```\n\nYou can add a fourth dimension by coloring the plot by a fourth variable. Notice how\nwe use `Tucan.Scale.set_color_scheme/3` to apply a semantically reasonable coloring and\n`Tucan.Legend.set_orientation/3` to change the default position of the two legends.\n\n```tucan\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month]\n)\n# we need to set recursive to true since this is a layered plot\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:size, \"bottom\")\n```","ref":"Tucan.html#punchcard/5-examples","title":"Examples - Tucan.punchcard/5","type":"function"},{"doc":"Adds a vertical or horizontal ruler at the given position.\n\n`position` can either be a number representing a coordinate of the _x/y-axis_ or a\nbinary representing a field. In the latter case an aggregation can also\nbe provided which will be used for aggregating the field distribution\nto a single number. If not set defaults to `:mean`.\n\n`axis` specifies the orientation of the line. Use `:x` for a vertical\nline and `:y` for a horizontal one.\n\nSee also `vruler/3`, `hruler/3`.","ref":"Tucan.html#ruler/4","title":"Tucan.ruler/4","type":"function"},{"doc":"* `:aggregate` (`t:atom/0`) - The aggregate to used for calculating the line's coordinate The default value is `:mean`.\n\n#","ref":"Tucan.html#ruler/4-options","title":"Options - Tucan.ruler/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#ruler/4-data-grouping-options","title":"Data Grouping Options - Tucan.ruler/4","type":"function"},{"doc":"* `:line_color` (`t:String.t/0`) - The color of the line The default value is `\"black\"`.\n* `:stroke_width` (`t:integer/0`) - The stroke width in pixels The default value is `1`.\n\n#","ref":"Tucan.html#ruler/4-styling-options","title":"Styling Options - Tucan.ruler/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.","ref":"Tucan.html#ruler/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.ruler/4","type":"function"},{"doc":"You can add a vertical ruler to any _x-axis_ point:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.ruler(:x, 1.1, stroke_width: 3, line_color: \"blue\")\n|> Tucan.ruler(:x, 1.4, line_color: \"green\")\n```\n\nAdditionally you can can add a vertical line to an aggregated value of\na data field. For example:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.ruler(:x, \"petal_width\", line_color: \"red\")\n```\n\nYou can add multiple lines for each group of the data if you pass the\n`color_by` option. Also you can combine vertical with horizontal\nlines.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.ruler(:x, \"petal_width\", color_by: \"species\", stroke_width: 3)\n|> Tucan.ruler(:y, \"petal_length\", color_by: \"species\")\n```","ref":"Tucan.html#ruler/4-examples","title":"Examples - Tucan.ruler/4","type":"function"},{"doc":"Returns the specification of a scatter plot with possibility of several semantic\ngroupings.\n\nBoth `x` and `y` must be `:quantitative`.\n\n> ##","ref":"Tucan.html#scatter/4","title":"Tucan.scatter/4","type":"function"},{"doc":">   \n> The relationship between `x` and `y` can be shown for different subsets of the\n> data using the `color_by`, `size_by` and `shape_by` parameters. This is equivalent\n> to calling the corresponding functions after a `scatter/4` call.\n> \n> These parameters control what visual semantics are used to identify the different\n> subsets. It is possible to show up to three dimensions independently by using all\n> three semantic types, but this style of plot can be hard to interpret and is often\n> ineffective.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"sex\",\n>   size_by: \"size\"\n> )\n> ```\n> \n> The above is equivalent to calling:\n>\n> ```elixir\n> Tucan.scatter(:tips, \"total_bill\", \"tip\")\n> |> Tucan.color_by(\"day\", type: :nominal)\n> |> Tucan.shape_by(\"sex\", type: :nominal)\n> |> Tucan.size_by(\"size\", type: :quantitative)\n> ```\n> \n> Using redundant semantics (i.e. both color and shape for the same variable) can be\n> helpful for making graphics more accessible.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"day\"\n> )\n> ```","ref":"Tucan.html#scatter/4-semantic-groupings-tip","title":"Semantic groupings {: .tip} - Tucan.scatter/4","type":"function"},{"doc":"#","ref":"Tucan.html#scatter/4-options","title":"Options - Tucan.scatter/4","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:shape_by` (`t:String.t/0`) - If set a data field that will be used for setting the shape of the data points.\n  It is considered `:nominal` by default.\n* `:size_by` (`t:String.t/0`) - If set a data field that will be used for controlling the size of the data points.\n  It is considered `:quantitative` by default.\n\n#","ref":"Tucan.html#scatter/4-data-grouping-options","title":"Data Grouping Options - Tucan.scatter/4","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:filled` (`t:boolean/0`) - Whether the mark will be filled or not\n* `:height` (`t:integer/0`) - Height of the image\n* `:point_color` (`t:String.t/0`) - The color of the points\n* `:point_shape` - Shape of the point marks. Circle by default.\n* `:point_size` (`t:pos_integer/0`) - The pixel area of the marks. Note that this value sets the area of the symbol;\n  the side lengths will increase with the square root of this value.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#scatter/4-styling-options","title":"Styling Options - Tucan.scatter/4","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:shape` (`t:keyword/0`) - Extra vega lite options for the `:shape` encoding. The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#scatter/4-encodings-custom-options","title":"Encodings Custom Options - Tucan.scatter/4","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#scatter/4-interactivity-options","title":"Interactivity Options - Tucan.scatter/4","type":"function"},{"doc":"> We will use the `:tips` dataset throughout the following examples.\n\nDrawing a scatter plot between two variables:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n```\n\nYou can modify the look of the plot by setting various styling options:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\",\n  point_color: \"red\",\n  point_shape: \"triangle-up\",\n  point_size: 10\n)\n```\n\nYou can combine it with `color_by/3` to color code the points with respect to\nanother variable:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n|> Tucan.color_by(\"time\")\n```\n\nAssigning the same variable to `shape_by/3` will also vary the markers and create a\nmore accessible plot:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"time\")\n|> Tucan.shape_by(\"time\")\n```\n\nAssigning `color_by/3` and `shape_by/3` to different variables will vary colors and\nmarkers independently:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"time\")\n```\n\nYou can also color the points by a numeric variable, the semantic mapping will be\nquantitative and will use a different default palette:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"size\", type: :quantitative)\n```\n\nA numeric variable can also be assigned to size to apply a semantic mapping to the\nareas of the points:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400, tooltip: :data)\n|> Tucan.color_by(\"size\", type: :quantitative)\n|> Tucan.size_by(\"size\", type: :quantitative)\n```\n\nYou can also combine it with `facet_by/3` in order to group within additional\ncategorical variables, and plot them across multiple subplots.\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.facet_by(:column, \"time\")\n```\n\nYou can also apply faceting on more than one variables, both horizontally and\nvertically:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.size_by(\"size\")\n|> Tucan.facet_by(:column, \"time\")\n|> Tucan.facet_by(:row, \"sex\")\n```","ref":"Tucan.html#scatter/4-examples","title":"Examples - Tucan.scatter/4","type":"function"},{"doc":"Sets the height of the plot (in pixels).","ref":"Tucan.html#set_height/2","title":"Tucan.set_height/2","type":"function"},{"doc":"Sets the plot size.\n\nThis sets both width and height at once.","ref":"Tucan.html#set_size/3","title":"Tucan.set_size/3","type":"function"},{"doc":"Sets the plot's theme.\n\nCheck `Tucan.Themes` for more details on theming.","ref":"Tucan.html#set_theme/2","title":"Tucan.set_theme/2","type":"function"},{"doc":"Sets the title of the plot.\n\nYou can optionally pass any title option supported by vega-lite to customize the\nstyle of it.","ref":"Tucan.html#set_title/3","title":"Tucan.set_title/3","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.set_title(\"My awesome plot\",\n    color: \"red\",\n    subtitle: \"with a subtitle\",\n    subtitle_color: \"green\",\n    anchor: \"start\"\n  )\n```","ref":"Tucan.html#set_title/3-examples","title":"Examples - Tucan.set_title/3","type":"function"},{"doc":"Sets the width of the plot (in pixels).","ref":"Tucan.html#set_width/2","title":"Tucan.set_width/2","type":"function"},{"doc":"Adds a `shape` encoding for the given field.","ref":"Tucan.html#shape_by/3","title":"Tucan.shape_by/3","type":"function"},{"doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#shape_by/3-options","title":"Options - Tucan.shape_by/3","type":"function"},{"doc":"Adds a `size` encoding for the given field.\n\nBy default the type of the `field` is set to `:quantitative`. You can override it in the\n`opts` by setting another `:type`.","ref":"Tucan.html#size_by/3","title":"Tucan.size_by/3","type":"function"},{"doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#size_by/3-options","title":"Options - Tucan.size_by/3","type":"function"},{"doc":"Returns the specification of a step chart.\n\nThis is a simple wrapper around `lineplot/4` with `:interpolate` set by default\nto `\"step\"`. If `:interpolate` is set to any of `step, step-before, step-after` it\nwill be used. In any other case defaults to `step`.","ref":"Tucan.html#step/4","title":"Tucan.step/4","type":"function"},{"doc":"Check `lineplot/4`","ref":"Tucan.html#step/4-options","title":"Options - Tucan.step/4","type":"function"},{"doc":"```tucan\nTucan.step(:stocks, \"date\", \"price\", color_by: \"symbol\", width: 300, x: [type: :temporal])\n|> Tucan.Scale.set_y_scale(:log)\n```","ref":"Tucan.html#step/4-examples","title":"Examples - Tucan.step/4","type":"function"},{"doc":"Returns the specification of a streamgraph.\n\nThis is a simple wrapper around `area/4` with `:mode` set by default\nto `:streamgraph`. Any value set to the `:mode` option will be ignored.\n\nA grouping field must also be provided which will be set as `:color_by` to\nthe area chart.","ref":"Tucan.html#streamgraph/5","title":"Tucan.streamgraph/5","type":"function"},{"doc":"Check `area/4`","ref":"Tucan.html#streamgraph/5-options","title":"Options - Tucan.streamgraph/5","type":"function"},{"doc":"```tucan\nTucan.streamgraph(:stocks, \"date\", \"price\", \"symbol\",\n  width: 300,\n  x: [type: :temporal],\n  tooltip: true\n)\n```","ref":"Tucan.html#streamgraph/5-examples","title":"Examples - Tucan.streamgraph/5","type":"function"},{"doc":"Draws a strip plot (categorical scatterplot).\n\nA strip plot is a single-axis scatter plot used to visualize the distribution of\na numerical field. The values are plotted as dots or ticks along one axis, so\nthe dots with the same value may overlap.\n\nYou can use the `:jitter` mode for a better view of overlapping points. In this\ncase points are randomly shifted along with other axis, which has no meaning in\nitself data-wise.\n\nTypically several strip plots are placed side by side to compare the distribution\nof a numerical value among several categories.","ref":"Tucan.html#stripplot/3","title":"Tucan.stripplot/3","type":"function"},{"doc":"* `:group` (`t:String.t/0`) - A field to be used for grouping the strip plot. If not set the plot will\n  be one dimensional.\n* `:style` - The style of the plot. Can be one of the following:\n    * `:tick` - use ticks for each data point\n    * `:point` - use points for each data point\n    * `:jitter` - use points but also apply some jittering across the other\n    axis\n\n  Use `:jitter` in case of many data points in order to avoid overlaps.\n\n  The default value is `:tick`.\n\n#","ref":"Tucan.html#stripplot/3-options","title":"Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#stripplot/3-data-grouping-options","title":"Data Grouping Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#stripplot/3-styling-options","title":"Styling Options - Tucan.stripplot/3","type":"function"},{"doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n* `:y_offset` (`t:keyword/0`) - Extra vega lite options for the `:y_offset` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#stripplot/3-encodings-custom-options","title":"Encodings Custom Options - Tucan.stripplot/3","type":"function"},{"doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used\n\n> #","ref":"Tucan.html#stripplot/3-interactivity-options","title":"Interactivity Options - Tucan.stripplot/3","type":"function"},{"doc":"> \n> If style is set to `:tick` the following `VegaLite` representation is generated:\n>\n> ```elixir\n> Vl.new()\n> |> Vl.mark(:tick)\n> |> Vl.encode_field(:x, field, type: :quantitative)\n> |> Vl.encode_field(:y, opts[:group], type: :nominal)\n> ```\n>\n> If style is set to `:jitter` then a transform is added to generate Gaussian jitter\n> using the Box-Muller transform, and the `y_offset` is also encoded based on this:\n>\n> ```elixir\n> Vl.new()\n> |> Vl.mark(:point)\n> |> Vl.transform(calculate: \"sqrt(-2*log(random()))*cos(2*PI*random())\", as: \"jitter\")\n> |> Vl.encode_field(:x, field, type: :quantitative)\n> |> Vl.encode_field(:y, opts[:group], type: :nominal)\n> |> Vl.encode_field(:y_offset, \"jitter\", type: :quantitative)\n> ```","ref":"Tucan.html#stripplot/3-internal-vegalite-representation-info","title":"Internal `VegaLite` representation {: .info} - Tucan.stripplot/3","type":"function"},{"doc":"Assigning a single numeric variable shows the univariate distribution. The default\nstyle is the `:tick`:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\")\n```\n\nFor very dense distribution it makes more sense to use the `:jitter` style in order\nto reduce overlapping points:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", style: :jitter, height: 30, width: 300)\n```\n\nYou can set the `:group` option in order to add a second dimension. Notice that\nthe field must be categorical.\n\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n```\n\nThe plot would be more clear if you also colored the points with the same field:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"day\")\n```\n\nOr you can color by a distinct variable to show a multi-dimensional relationship:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"sex\")\n```\n\nor you can color by a numerical variable:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n|> Tucan.color_by(\"size\", type: :ordinal)\n```\n\nYou could draw the same with points but without jittering:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :point)\n|> Tucan.color_by(\"sex\")\n```\n\nor with ticks which is the default one:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :tick)\n|> Tucan.color_by(\"sex\")\n```\n\nYou can set the `:orient` flag to `:vertical` to change the orientation:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter, orient: :vertical)\n|> Tucan.color_by(\"sex\")\n```","ref":"Tucan.html#stripplot/3-examples","title":"Examples - Tucan.stripplot/3","type":"function"},{"doc":"Adds a `stroke_dash` encoding for the given field.","ref":"Tucan.html#stroke_dash_by/3","title":"Tucan.stroke_dash_by/3","type":"function"},{"doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#stroke_dash_by/3-options","title":"Options - Tucan.stroke_dash_by/3","type":"function"},{"doc":"Concatenates vertically the given plots.","ref":"Tucan.html#vconcat/2","title":"Tucan.vconcat/2","type":"function"},{"doc":"Adds a vertical line at the given `x` position.\n\nFor supported options check `line/4`.","ref":"Tucan.html#vruler/3","title":"Tucan.vruler/3","type":"function"},{"doc":"","ref":"Tucan.html#t:field/0","title":"Tucan.field/0","type":"type"},{"doc":"","ref":"Tucan.html#t:plotdata/0","title":"Tucan.plotdata/0","type":"type"},{"doc":"Utilities for configuring plot axes.","ref":"Tucan.Axes.html","title":"Tucan.Axes","type":"module"},{"doc":"Sets an arbitrary set of options to the given `encoding` axis object.\n\nNotice that no validation is performed, any option set will be merged with\nthe existing `axis` options of the given `encoding`.\n\nAn `ArgumentError` is raised if the given encoding channel is not defined.","ref":"Tucan.Axes.html#put_options/3","title":"Tucan.Axes.put_options/3","type":"function"},{"doc":"Set the title of the given `axis`.","ref":"Tucan.Axes.html#set_title/3","title":"Tucan.Axes.set_title/3","type":"function"},{"doc":"Sets the x axis title.","ref":"Tucan.Axes.html#set_x_title/2","title":"Tucan.Axes.set_x_title/2","type":"function"},{"doc":"Sets the _x-axis_ and _y-axis_ titles at once.","ref":"Tucan.Axes.html#set_xy_titles/3","title":"Tucan.Axes.set_xy_titles/3","type":"function"},{"doc":"Sets the y axis title.","ref":"Tucan.Axes.html#set_y_title/2","title":"Tucan.Axes.set_y_title/2","type":"function"},{"doc":"","ref":"Tucan.Axes.html#t:axis/0","title":"Tucan.Axes.axis/0","type":"type"},{"doc":"Helper utilities for customizing a plot's grid.","ref":"Tucan.Grid.html","title":"Tucan.Grid","type":"module"},{"doc":"Set a specific color to the grid for the given channel.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_color/3","title":"Tucan.Grid.set_color/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:y, \"red\")\n|> Tucan.Grid.set_color(:x, \"#2A32F4\")\n```","ref":"Tucan.Grid.html#set_color/3-examples","title":"Examples - Tucan.Grid.set_color/3","type":"function"},{"doc":"Sets the dash style of the grid.\n\n`stroke` and `space` are alternative lengths for the dashed grid lines in pixels.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_dash_style/4","title":"Tucan.Grid.set_dash_style/4","type":"function"},{"doc":"A scatter plot with the different dashed styles across the two axes:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_dash_style(:x, 10, 2)\n|> Tucan.Grid.set_dash_style(:y, 2, 10)\n```","ref":"Tucan.Grid.html#set_dash_style/4-examples","title":"Examples - Tucan.Grid.set_dash_style/4","type":"function"},{"doc":"Enables or disables the grid for the plot.\n\nNotice that the grid is enabled by default.\n\nSee also `set_enabled/3` for enabling/disabling specific axis' grid.","ref":"Tucan.Grid.html#set_enabled/2","title":"Tucan.Grid.set_enabled/2","type":"function"},{"doc":"A scatter plot with the grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(false)\n```","ref":"Tucan.Grid.html#set_enabled/2-examples","title":"Examples - Tucan.Grid.set_enabled/2","type":"function"},{"doc":"Enable or disable the grid of a specific `channel`\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_enabled/3","title":"Tucan.Grid.set_enabled/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(:y, false)\n```","ref":"Tucan.Grid.html#set_enabled/3-examples","title":"Examples - Tucan.Grid.set_enabled/3","type":"function"},{"doc":"Sets the opacity of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_opacity/3","title":"Tucan.Grid.set_opacity/3","type":"function"},{"doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color and\nopacity values set. Also the width is increased to make the opacity changes more clear.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:x, \"red\")\n|> Tucan.Grid.set_color(:y, \"cyan\")\n|> Tucan.Grid.set_opacity(:x, 0.1)\n|> Tucan.Grid.set_opacity(:y, 0.8)\n|> Tucan.Grid.set_width(:x, 3)\n|> Tucan.Grid.set_width(:y, 3)\n```","ref":"Tucan.Grid.html#set_opacity/3-examples","title":"Examples - Tucan.Grid.set_opacity/3","type":"function"},{"doc":"Sets the width of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_width/3","title":"Tucan.Grid.set_width/3","type":"function"},{"doc":"Helper utilities for configuring the plot legend.","ref":"Tucan.Legend.html","title":"Tucan.Legend","type":"module"},{"doc":"Set arbitrary options to the legend of the given channel.\n\nThe options are deep merged with existing options.","ref":"Tucan.Legend.html#put_options/3","title":"Tucan.Legend.put_options/3","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.Legend.put_options(:color, fill_color: \"yellow\", offset: 5, padding: 2, label_font_size: 14)\n```","ref":"Tucan.Legend.html#put_options/3-examples","title":"Examples - Tucan.Legend.put_options/3","type":"function"},{"doc":"Enables or disables the legend of the given encoding channel.","ref":"Tucan.Legend.html#set_enabled/3","title":"Tucan.Legend.set_enabled/3","type":"function"},{"doc":"Sets the legend orientation with respect to the scene.\n\nYou need to define the `channel` for which the legend will be configured. Orientation\ncan be one of the following: `[\"left\", \"right\", \"top\", \"bottom\", \"top-left\", \"top-right\", \"bottom-left\", \"bottom-right\", \"none\"]`.\n\nApplicable only on plots with a legend.","ref":"Tucan.Legend.html#set_orientation/3","title":"Tucan.Legend.set_orientation/3","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:shape, \"top\")\n```","ref":"Tucan.Legend.html#set_orientation/3-examples","title":"Examples - Tucan.Legend.set_orientation/3","type":"function"},{"doc":"Sets the title of the given legend.\n\nYou can optionally pass any title option supported by vega-lite to customize the\nstyle of it.\n\nApplicable only on plots with a legend.","ref":"Tucan.Legend.html#set_title/4","title":"Tucan.Legend.set_title/4","type":"function"},{"doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.Legend.set_title(:color, \"Iris Species\", title_color: \"red\", title_font_weight: 300)\n```","ref":"Tucan.Legend.html#set_title/4-examples","title":"Examples - Tucan.Legend.set_title/4","type":"function"},{"doc":"Utilities for working with Vega-Lite scales.\n\nScales are functions that transform a domain of data values (numbers, dates, strings, etc.)\nto a range of visual values (pixels, colors, sizes).\n\nThis module exposes various helper functions for setting various scale options like\nthe color scheme, the domain or the scale type.","ref":"Tucan.Scale.html","title":"Tucan.Scale","type":"module"},{"doc":"Sets an arbitrary set of options to the given `encoding`'s scake object.\n\nNotice that no validation is performed, any option set will be merged with\nthe existing `scale` options of the given `encoding`.\n\nAn `ArgumentError` is raised if the given encoding channel is not defined.","ref":"Tucan.Scale.html#put_options/3","title":"Tucan.Scale.put_options/3","type":"function"},{"doc":"Sets the color scheme.\n\nYou can either set one of the predefined schemes, or an array of colors which will\nbe used as the color range.\n\nThe input plot must be a single view with a color encoding defined.","ref":"Tucan.Scale.html#set_color_scheme/3","title":"Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"* `:reverse` (`t:boolean/0`) - If set to `true` the selected scheme is reversed. Ignored if a range is set. The default value is `false`.","ref":"Tucan.Scale.html#set_color_scheme/3-options","title":"Options - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"All [vega supported schemes](https://vega.github.io/vega/docs/schemes/) are supported\nby `Tucan`.\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-supported-color-schemes","title":"Supported color schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Categorical color schemes can be used to encode discrete data values, each representing\na distinct category.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-categorical-schemes","title":"Categorical Schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Sequential color schemes can be used to encode quantitative values. These\ncolor ramps are designed to encode increasing numeric values.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-sequential-single-hue-schemes","title":"Sequential Single-Hue Schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Sequential color schemes can be used to encode quantitative values. These color\nramps are designed to encode increasing numeric values, but use additional\nhues for more color discrimination, which may be useful for visualizations\nsuch as heatmaps.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-sequential-multi-hue-schemes","title":"Sequential Multi-Hue Schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"#","ref":"Tucan.Scale.html#set_color_scheme/3-schemes-for-dark-backgrounds","title":"Schemes for Dark Backgrounds - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"#","ref":"Tucan.Scale.html#set_color_scheme/3-schemes-for-light-backgrounds","title":"Schemes for Light Backgrounds - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Diverging color schemes can be used to encode quantitative values with a meaningful\nmid-point, such as zero or the average value. Color ramps with different hues\ndiverge with increasing saturation to highlight the values below and above the\nmid-point.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-diverging-schemes","title":"Diverging Schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Cyclical color schemes may be used to highlight periodic patterns in continuous\ndata. However, these schemes are not well suited to accurately convey value\ndifferences.","ref":"Tucan.Scale.html#set_color_scheme/3-cyclical-schemes","title":"Cyclical Schemes - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Setting a specific color range\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.Scale.set_color_scheme([\"yellow\", \"black\", \"#f234c1\"])\n```\n\nYou can set any of the predefined color schemes to any plot with a color\nencoding.\n\n```tucan\nTucan.scatter(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :monthdate],\n  y: [aggregate: :mean],\n  color_by: \"temp_max\",\n  color: [aggregate: :mean, type: :quantitative],\n  width: 400\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue)\n\n```\n\nYou can reverse it by setting the `:reverse` option:\n\n```tucan\nTucan.scatter(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :monthdate],\n  y: [aggregate: :mean],\n  color_by: \"temp_max\",\n  color: [aggregate: :mean, type: :quantitative],\n  width: 400\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n\n```","ref":"Tucan.Scale.html#set_color_scheme/3-examples","title":"Examples - Tucan.Scale.set_color_scheme/3","type":"function"},{"doc":"Sets the domain for the given encoding channel.\n\n`domain` can be anything Vega-Lite supports and the validity of it depends on the type\nof the encoding's data.\n\nNotice that no validation is performed.","ref":"Tucan.Scale.html#set_domain/3","title":"Tucan.Scale.set_domain/3","type":"function"},{"doc":"Sets the _x-axis_ domain.\n\nThis is a helper wrapper around `set_domain/3` for setting the domain of continuous\nscales.","ref":"Tucan.Scale.html#set_x_domain/3","title":"Tucan.Scale.set_x_domain/3","type":"function"},{"doc":"Sets the x axis scale.\n\nNotice that only continuous scales are supported.","ref":"Tucan.Scale.html#set_x_scale/2","title":"Tucan.Scale.set_x_scale/2","type":"function"},{"doc":"Sets the _y-axis_ domain.\n\nThis is a helper wrapper around `set_domain/3` for setting the domain of continuous\nscales.","ref":"Tucan.Scale.html#set_y_domain/3","title":"Tucan.Scale.set_y_domain/3","type":"function"},{"doc":"Sets the y axis scale.\n\nNotice that only continuous scales are supported.","ref":"Tucan.Scale.html#set_y_scale/2","title":"Tucan.Scale.set_y_scale/2","type":"function"},{"doc":"","ref":"Tucan.Scale.html#t:color_scheme/0","title":"Tucan.Scale.color_scheme/0","type":"type"},{"doc":"Helper functions for `Tucan` theme.\n\nA `Tucan` theme is nothing more than a keyword list with a `VegaLite` configuration\nobject with some styles applied and some metadata. Every theme must have the\nfollowing format:\n\n    [\n       theme: [],          # the actual theme configuration\n       name: :name,        # an atom with a unique name\n       doc: \"description\", # a description of the theme,\n       source: \"url\"       # a url to the source of the theme if any for attribution \n    ]","ref":"Tucan.Themes.html","title":"Tucan.Themes","type":"module"},{"doc":"`Tucan` comes pre-packed with a set of themes, borrowed by the [Vega Themes](https://github.com/vega/vega-themes)\nproject. You can set a theme to a plot by calling the `Tucan.set_theme/2` function. If no\ntheme set the default vega-lite theme is used. In all examples below the following example\nplot is used:\n\n```tucan\nscatter =\n  Tucan.scatter(:iris, \"petal_width\", \"petal_length\", tooltip: true)\n  |> Tucan.color_by(\"species\")\n  |> Tucan.shape_by(\"species\")\n\nlines = Tucan.lineplot(:stocks, \"date\", \"price\", color_by: \"symbol\", x: [type: :temporal])\n\narea =\n  Tucan.area(:stocks, \"date\", \"price\", color_by: \"symbol\", mode: :normalize, x: [type: :temporal])\n\ndensity = Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n\nstrip =\n  Tucan.stripplot(:tips, \"total_bill\", group: \"day\", style: :jitter)\n  |> Tucan.color_by(\"sex\")\n\nboxplot = Tucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\nhistogram = Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n\npie = Tucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\ndonut = Tucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\nheatmap =\n  Tucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n\nTucan.vconcat(\n  [\n    Tucan.hconcat([scatter, lines, area]),\n    Tucan.hconcat([density, Tucan.vconcat([strip, boxplot]), histogram]),\n    Tucan.hconcat([pie, donut, heatmap])\n  ]\n)\n|> VegaLite.config(legend: [disable: true])\n|> VegaLite.resolve(:scale, color: :independent)\n\n```\n\nThe following themes are currently supported:\n\n### `:dark`\n\nA dark theme [[source](https://github.com/vega/vega-themes/blob/main/src/theme-dark.ts)]\n\n**Example:**\n\n\n\n\n### `:excel`\n\nChart theme modeled after `excel` [[source](https://github.com/vega/vega-themes/blob/main/src/theme-excel.ts)]\n\n**Example:**\n\n\n\n\n### `:five_thirty_eight`\n\nChart theme modeled after FiveThirtyEight [[source](https://github.com/vega/vega-themes/blob/main/src/theme-fivethirtyeight.ts)]\n\n**Example:**\n\n\n\n\n### `:ggplot2`\n\nChart theme modeled after `ggplot2` [[source](https://github.com/vega/vega-themes/blob/main/src/theme-ggplot2.ts)]\n\n**Example:**\n\n\n\n\n### `:google_charts`\n\nChart theme modeled after Google Charts [[source](https://github.com/vega/vega-themes/blob/main/src/theme-googlecharts.ts)]\n\n**Example:**\n\n\n\n\n### `:latimes`\n\nChart theme modeled after the Los Angeles Times [[source](https://github.com/vega/vega-themes/blob/main/src/theme-latimes.ts)]\n\n**Example:**\n\n\n\n\n### `:power_bi`\n\nChart theme modeled after Power BI [[source](https://github.com/vega/vega-themes/blob/main/src/theme-powerbi.ts)]\n\n**Example:**\n\n\n\n\n### `:quartz`\n\nChart theme modeled after Quartz [[source](https://github.com/vega/vega-themes/blob/main/src/theme-quartz.ts)]\n\n**Example:**\n\n\n\n\n### `:urban_institute`\n\nChart theme modeled after Urban Institute [[source](https://github.com/vega/vega-themes/blob/main/src/theme-urbaninstitute.ts)]\n\n**Example:**\n\n\n\n\n### `:vox`\n\nChart theme modeled after Vox [[source](https://github.com/vega/vega-themes/blob/main/src/theme-vox.ts)]\n\n**Example:**","ref":"Tucan.Themes.html#module-default-themes","title":"Default themes - Tucan.Themes","type":"module"},{"doc":"Returns the configuration object for the given theme.\n\nAn exception will be raised if the theme name is invalid.","ref":"Tucan.Themes.html#theme/1","title":"Tucan.Themes.theme/1","type":"function"},{"doc":"Common datasets for `Tucan` demos and docs.","ref":"Tucan.Datasets.html","title":"Tucan.Datasets","type":"module"},{"doc":"Currently the following datasets are supported:\n\n##","ref":"Tucan.Datasets.html#module-supported-datasets","title":"Supported datasets - Tucan.Datasets","type":"module"},{"doc":"[Yield data](https://stat.ethz.ch/R-manual/R-devel/library/lattice/html/barley.html) from a\nMinnesota barley trial. Includes total yield in bushels per acre for 10 varieties at 6 sites\nin each of two years.\n [[Data]](https://vega.github.io/editor/data/barley.json).\n\n**Columns: ** `yield`, `variety`, `year`, `site`\n\n##","ref":"Tucan.Datasets.html#module-barley","title":"barley - Tucan.Datasets","type":"module"},{"doc":"This was the 1983 ASA Data Exposition dataset. The dataset was collected by Ernesto Ramos and\nDavid Donoho and dealt with automobiles. I don't remember the instructions for analysis. Data\non mpg, cylinders, displacement, etc. (8 variables) for 406 different cars. [[Source]](http://lib.stat.cmu.edu/datasets/)\n [[Data]](https://vega.github.io/editor/data/cars.json).\n\n**Columns: ** `Name`, `Miles_per_Gallon`, `Cylinders`, `Displacement`, `Horsepower`, `Weight_in_lbs`, `Acceleration`, `Year`, `Origin`\n\n##","ref":"Tucan.Datasets.html#module-cars","title":"cars - Tucan.Datasets","type":"module"},{"doc":"Corruption Perceptions Index (CPI) and Human Development Index (HDI) for 176 countries,\nfrom 2012 to 2015.\n [[Data]](https://raw.githubusercontent.com/holtzy/The-Python-Graph-Gallery/master/static/data/corruption.csv).\n\n**Columns: ** `country`, `region`, `year`, `cpi`, `iso3c`, `hdi`\n\n##","ref":"Tucan.Datasets.html#module-corruption","title":"corruption - Tucan.Datasets","type":"module"},{"doc":"Monthly airline passengers from 1949 to 1960. \n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/flights.csv).\n\n**Columns: ** `year`, `month`, `passengers`\n\n##","ref":"Tucan.Datasets.html#module-flights","title":"flights - Tucan.Datasets","type":"module"},{"doc":"[Gapminder](https://www.gapminder.org/) health & income by country data.\n [[Data]](https://vega.github.io/vega-datasets/data/gapminder-health-income.csv).\n\n**Columns: ** `country`, `income`, `health`, `population`, `region`\n\n##","ref":"Tucan.Datasets.html#module-gapminder","title":"gapminder - Tucan.Datasets","type":"module"},{"doc":"Data from the [GLUE (The General Language Understanding Evaluation) benchmark\nleaderboard](https://gluebenchmark.com/leaderboard).\n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/glue.csv).\n\n**Columns: ** `Model`, `Year`, `Encoder`, `Task`, `Score`\n\n##","ref":"Tucan.Datasets.html#module-glue","title":"glue - Tucan.Datasets","type":"module"},{"doc":"This is one of the earliest datasets used in the literature on classification methods and widely\nused in statistics and machine learning.  The data set contains 3 classes of 50 instances each,\nwhere each class refers to a type of iris plant.\n [[Data]](https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv).\n\n**Columns: ** `sepal_length`, `sepal_width`, `petal_length`, `petal_width`, `species`\n\n##","ref":"Tucan.Datasets.html#module-iris","title":"iris - Tucan.Datasets","type":"module"},{"doc":"Movies dataset including IMDB scores. The dataset has well known and intentionally included\nerrors. This dataset is used for instructional purposes, including the need to reckon with\ndirty data.\n [[Data]](https://vega.github.io/editor/data/movies.json).\n\n**Columns: ** `Creative Type`, `Director`, `Distributor`, `IMDB Rating`, `IMDB Votes`, `MPAA Rating`, `Major Genre`, `Production Budget`, `Release Date`, `Rotten Tomatoes Rating`, `Running Time min`, `Source`, `Title`, `US DVD Sales`, `US Gross`, `Worldwide Gross`\n\n##","ref":"Tucan.Datasets.html#module-movies","title":"movies - Tucan.Datasets","type":"module"},{"doc":"The [dataset](https://github.com/allisonhorst/palmerpenguins) contains data for 344 penguins.\nThere are 3 different species of penguins in this dataset, collected from 3 islands in the\nPalmer Archipelago, Antarctica. This is an excellent dataset for data exploration\n& visualization, as an alternative to `:iris`.\n\nData were collected and made available by [Dr. Kristen Gorman](https://www.uaf.edu/cfos/people/faculty/detail/kristen-gorman.php)\nand the [Palmer Station, Antarctica LTER](https://pallter.marine.rutgers.edu/), a member of\nthe [Long Term Ecological Research Network](https://lternet.edu/).\n [[Data]](https://raw.githubusercontent.com/vega/vega-datasets/next/data/penguins.json).\n\n**Columns: ** `Beak Depth (mm)`, `Beak Length (mm)`, `Body Mass (g)`, `Flipper Length (mm)`, `Island`, `Sex`, `Species`\n\n##","ref":"Tucan.Datasets.html#module-penguins","title":"penguins - Tucan.Datasets","type":"module"},{"doc":"Daily closing prices of various stocks. [[Data]](https://vega.github.io/editor/data/stocks.csv).\n\n**Columns: ** `symbol`, `date`, `price`\n\n##","ref":"Tucan.Datasets.html#module-stocks","title":"stocks - Tucan.Datasets","type":"module"},{"doc":"[Tipping data](https://rdrr.io/cran/reshape2/man/tips.html) as collected by one waiter.\nInformation about each tip he received over a period of a few months working in one restaurant\nis included.\n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/tips.csv).\n\n**Columns: ** `total_bill`, `tip`, `sex`, `smoker`, `day`, `time`, `size`\n\n##","ref":"Tucan.Datasets.html#module-tips","title":"tips - Tucan.Datasets","type":"module"},{"doc":"Titanic survival data from the [legendary Kaggle competition](https://www.kaggle.com/competitions/titanic/data).\n [[Data]](https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv).\n\n**Columns: ** `PassengerId`, `Survived`, `Pclass`, `Name`, `Sex`, `Age`, `SibSp`, `Parch`, `Ticket`, `Fare`, `Cabin`, `Embarked`\n\n##","ref":"Tucan.Datasets.html#module-titanic","title":"titanic - Tucan.Datasets","type":"module"},{"doc":"US unemployment data across various industries from 2000 to 2009.\n [[Data]](https://vega.github.io/editor/data/unemployment-across-industries.json).\n\n**Columns: ** `count`, `date`, `month`, `rate`, `series`, `year`\n\n##","ref":"Tucan.Datasets.html#module-unemployment","title":"unemployment - Tucan.Datasets","type":"module"},{"doc":"Daily weather records from Seattle with metric units. [Data from NOAA](https://www.ncdc.noaa.gov/cdo-web/datatools/records).\n [[Data]](https://vega.github.io/editor/data/weather.csv).\n\n**Columns: ** `date`, `precipitation`, `temp_max`, `temp_min`, `wind`, `weather`","ref":"Tucan.Datasets.html#module-weather","title":"weather - Tucan.Datasets","type":"module"},{"doc":"Reruns the url of the given dataset.\n\nRaises an error if the dataset is invalid.","ref":"Tucan.Datasets.html#dataset/1","title":"Tucan.Datasets.dataset/1","type":"function"},{"doc":"","ref":"Tucan.Datasets.html#t:t/0","title":"Tucan.Datasets.t/0","type":"type"},{"doc":"# Tucan\n\n[![Actions Status](https://github.com/pnezis/tucan/actions/workflows/elixir.yml/badge.svg)](https://github.com/pnezis/tucan/actions)\n[![Package](https://img.shields.io/badge/-Package-important)](https://hex.pm/packages/tucan)\n[![Documentation](https://img.shields.io/badge/-Documentation-blueviolet)](https://hexdocs.pm/tucan/Tucan.html)\n\n`Tucan` is an Elixir plotting library built on top of `VegaLite`, designed to simplify\nthe creation of interactive and visually stunning plots. With `Tucan`, you can effortlessly\ngenerate a wide range of plots, from simple bar charts to complex composite plots, all\nwhile enjoying the power and flexibility of a clean composable functional API.\n\n`Tucan` offers a simple API for creating most common plot types similarly to `matplotlib`\nand `seaborn` without requiring the end user to be familiar with the Vega Lite grammar.\n\n![Tucan](https://github.com/pnezis/tucan/raw/main/assets/tucan.png)","ref":"readme.html","title":"Tucan","type":"extras"},{"doc":"- **Versatile Plot Types** - `Tucan` provides an array of plot types, including bar charts,\nline plots, scatter plots, histograms, and more, allowing you to effectively represent\ndiverse data sets.\n- **Clean and consistent API** - A clean and consistent plotting API similar to `matplotlib`\nor `seaborn` is provided. You should be able to create most common plots with a single\nfunction call and minimal configuration.\n- **Grouping and Faceting** - Enhance your visualizations with grouping and faceting\nfeatures, enabling you to examine patterns and trends within subgroups of your data.\n- **Customization** - Customize your plots with ease using Tucan's utilities for adjusting\nplot dimensions, titles, and **themes**.\n- **Thin wrapper on top of VegaLite** - All `VegaLite` functions can be used seamlessly with\n`Tucan` in order to enhance/customize your plots.\n- **Low level API** - A low level API with helper functions is provided for modifying\n`VegaLite` specifications.","ref":"readme.html#features","title":"Features - Tucan","type":"extras"},{"doc":"```elixir\n# A simple scatter plot\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n\n# You can combine it with one or more semantic grouping functions\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n\n# You can pipe it through other Tucan functions to modify the look & feel\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\",\n  color_by: \"region\",\n  tooltip: true\n)\n|> Tucan.set_width(400)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n\n# Some composite plots are also supported\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, , width: 130, height: 130)\n|> Tucan.color_by(\"species\", recursive: true)\n\n# creating facet plots is very easy with the facet_by/4 function\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.facet_by(:column, \"species\")\n|> Tucan.color_by(\"species\")\n```\n\nRead the [docs](https://hexdocs.pm/tucan/Tucan.html) for more examples.","ref":"readme.html#basic-usage","title":"Basic usage - Tucan","type":"extras"},{"doc":"#","ref":"readme.html#installation","title":"Installation - Tucan","type":"extras"},{"doc":"You most likely want to use Tucan in [Livebook](https://github.com/livebook-dev/livebook),\nin which case you can call `Mix.install/2`:\n\n```elixir\nMix.install([\n  {:tucan, \"~> 0.2.0\"},\n  {:kino_vega_lite, \"~> 0.1.8\"}\n])\n```\n\nYou will also want [kino_vega_lite](https://github.com/livebook-dev/kino_vega_lite) to ensure\nLivebook renders the graphics nicely.\n\n#","ref":"readme.html#inside-livebook","title":"Inside Livebook - Tucan","type":"extras"},{"doc":"You can add the `:tucan` dependency to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tucan, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#in-mix-projects","title":"In Mix projects - Tucan","type":"extras"},{"doc":"- [vega-lite](https://vega.github.io/vega-lite/) and the awesome docs of it, many examples\nand most of the datasets used are based on it.\n- The elixir [VegaLite](https://github.com/livebook-dev/vega_lite) bindings\n- [seaborn](https://seaborn.pydata.org/), [matplotlib](https://matplotlib.org/) and\n[ggplot2](https://ggplot2.tidyverse.org/) upon which the high level API is partially based.\n- [vega-themes](https://github.com/vega/vega-themes) from which the existing themes are\nported.","ref":"readme.html#acknowledgements","title":"Acknowledgements - Tucan","type":"extras"},{"doc":"Copyright (c) 2023 Panagiotis Nezis\n\nTucan is released under the MIT License. See the [LICENSE](LICENSE) file for more details.","ref":"readme.html#license","title":"License - Tucan","type":"extras"},{"doc":"# Changelog\n\n## [v0.2.0](https://github.com/pnezis/tucan/tree/v0.2.0) (2023-09-23)\n\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Add `Tucan.jointplot/4` composite plot.\n\n```tucan\n  Tucan.jointplot(\n    :penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\",\n    marginal: :density,\n    color_by: \"Species\",\n    marginal_opts: [fill_opacity: 0.5]\n  )\n```\n\n- Add `Tucan.punchcard/5` plot. This is similar to heatmap but the third\ndimension is encoded by size instead of color.\n\n```tucan\nTucan.punchcard(:glue, \"Task\", \"Model\", \"Score\")\n|> Tucan.color_by(\"Score\", recursive: true, type: :quantitative)\n|> Tucan.set_size(250, 250)\n```\n\n- Add `Tucan.heatmap/5` plot.\n\n```tucan\nTucan.heatmap(:glue, \"Task\", \"Model\", \"Score\", annotate: true, text: [format: \".1f\"])\n|> Tucan.set_size(250, 250)\n```\n\n- Add `Tucan.hruler/2`, `Tucan.vruler/2` and `Tucan.ruler/4` helpers.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", width: 300)\n|> Tucan.hruler(3, line_color: \"green\")\n|> Tucan.vruler(\"petal_width\", color_by: \"species\", stroke_width: 3)\n|> Tucan.hruler(\"petal_length\", color_by: \"species\")\n```\n\n- Add `Tucan.Legend` module for customizing legend properties.\n- Add `Tucan.Scale` helper module with helper functions for working with\nscales, like `Tucan.Scale.set_color_scheme/3`.\n- Add `Tucan.set_size/3` helper for setting both width and height at once.\n- Add `Tucan.Axes.set_xy_titles/3` for setting axes titles at once.\n- Port more themes from `vega-themes`, check `Tucan.Themes` for all\navailable themes.\n\n- Add `Tucan.layers/2` helper\n\n```tucan\nTucan.layers(\n  [\n    Tucan.scatter(:iris, \"petal_width\", \"petal_length\", point_color: \"red\"),\n    Tucan.scatter(:iris, \"sepal_width\", \"sepal_length\", point_color: \"green\")\n  ]\n)\n```\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Support `:filled` option in `Tucan.scatter/4`\n- Support `:wrapped` mode in `Tucan.facet_by/4`\n- Support `:color_by` option in `Tucan.stripplot/3`\n- Support `:line_color` option in `Tucan.lineplot/4`\n- Support `:point_color`, `:point_shape` and `:point_size` in `Tucan.scatter/4`\n\n#","ref":"changelog.html#added-plots-options","title":"Added plots options - Changelog","type":"extras"},{"doc":"- Support setting `:orient` in `Tucan.density/3`.\n- Make size encodings quantitative by default.\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Made `Tucan.VegaLiteUtils` private.\n- `Tucan.Axes.put_axis_options` is renamed to `Tucan.Axes.put_options/3`\n- Rename `:groupby` to `:group_by` in `Tucan.boxplot/3` options. \n\n## [v0.1.1](https://github.com/pnezis/tucan/tree/v0.1.1) (2023-08-29)\n\n#","ref":"changelog.html#deprecated","title":"Deprecated - Changelog","type":"extras"},{"doc":"- Add `concat/2`, `hconcat/2` and `vconcat/2` helper concatenation functions.\n\n## [v0.1.0](https://github.com/pnezis/tucan/tree/v0.1.0) (2023-08-28)\n\nInitial release.","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"# MIT License\n\nCopyright (c) 2023 Panagiotis Nezis\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"},{"doc":"# Time Series Plots in Tucan\n\n```elixir\n# Comment this out for running from the path\n# System.put_env(\"TUCAN_DEV\", \"true\")\n\ntucan_version =\n  case System.get_env(\"TUCAN_DEV\") do\n    nil -> \"0.2.0\"\n    _other -> [path: Path.expand(\"..\", __DIR__)]\n  end\n\nMix.install([\n  {:tucan, tucan_version},\n  {:kino_vega_lite, \"~> 0.1.9\"}\n])\n\nalias VegaLite, as: Vl\n```","ref":"time_series_plots_in_tucan.html","title":"Time Series Plots in Tucan","type":"extras"},{"doc":"_This tutorial is an adaptation to Tucan of [Basic Time Series Plots in Vega-Lite](https://observablehq.com/@jonfroehlich/basic-time-series-plots-in-vega-lite?collection=@jonfroehlich/intro-to-vega-lite) by Jon E. Froehlich_\n\nWe will explore creating visualizations of **Seattle's daily maximum temperature** showing how to use position, color, and size to create multi-dimensional plots. We will create temporal scatter plots, dot/strip plots, heatmaps, and bubble plots.\n\nWe will then show how to use Tucan's functionalities to calculate and plot average monthly weather data.","ref":"time_series_plots_in_tucan.html#introduction","title":"Introduction - Time Series Plots in Tucan","type":"extras"},{"doc":"> Throughout this notebook we will use the `:weather` dataset that comes with `Tucan`.\n\nWe can start by using `Tucan.scatter/4 ` to plot all dataset points. Let's encode time on the _x-axis_ and `temp_max` on the _y-axis_. By default `scatter` expects two quantitative variables. We have to specify that the _x-axis_ encodes time by explicitely setting the `type` to `temporal` through the `:x` option.\n\nWe set the `filled` option to `true` in order to have filled points and enable the `tooltip` in order to add some interactivity.\n\n```elixir\nmax_temp_scatter =\n  Tucan.scatter(:weather, \"date\", \"temp_max\", filled: true, x: [type: :temporal], tooltip: true)\n  |> Tucan.set_size(700, 400)\n  |> Tucan.set_title(\"Daily Max Temperatures in Seattle 2012 - 2015\")\n  |> Tucan.Axes.set_y_title(\"Max Temperature\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#our-first-visualization-scatter","title":"Our first visualization - scatter - Time Series Plots in Tucan","type":"extras"},{"doc":"We can also add **weather** as an additional encoding channel using color. To control the color palette, we set the color scale.\n\nSince we want to control the visual values, we specify a range. We carefully choose a palette that has semantic meaning: yellow for sun, gray for fog, blue for rain, etc.\n\nYou can either pipe the previous plot through `Tucan.color_by/3` or set directly the `color_by` option to the `Tucan.scatter/4` call.\n\n```elixir\ncolor_palette = [\"#aec7e8\", \"#c7c7c7\", \"#1f77b4\", \"#9467bd\", \"#e7ba52\"]\n\nTucan.color_by(max_temp_scatter, \"weather\")\n|> Tucan.Scale.set_color_scheme(color_palette)\n```\n\n#","ref":"time_series_plots_in_tucan.html#semantic-grouping-by-color","title":"Semantic grouping by color - Time Series Plots in Tucan","type":"extras"},{"doc":"We can also control the size of the points by a fourth variable. Let's use `precipitation` for this. Notice that we also set the range of the `size` encoding in order to ensure that all points are included in the graph.\n\nNotice how the tooltip content changes with respect to the encoded parameters.\n\n```elixir\nmax_temp_scatter\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.size_by(\"precipitation\", scale: [range: [5, 350]])\n```\n\n#","ref":"time_series_plots_in_tucan.html#semantic-grouping-by-size","title":"Semantic grouping by size - Time Series Plots in Tucan","type":"extras"},{"doc":"To track seasonal patterns, let's aggregate the temporal dimension around the `monthdate` time unit, which is sensitive to month and date but not year—and can be useful for binning time values to look at seasonal patterns.\n\nLet's also specifically format the _x-axis_ date format to print out the abbreviated month name. See [Vega-Lite's text format documentation](https://vega.github.io/vega-lite/docs/format.html) for more details. We will use the `Tucan.Axes.put_options/3` helper which can set any option on the given axis.\n\nAlso notice that the `:y` option (like all encoding options) can be used to set any arbitrary option to the `y` encoding channel.\n\n```elixir\naggregated_scatter =\n  Tucan.scatter(:weather, \"date\", \"temp_max\",\n    x: [type: :temporal, time_unit: :monthdate],\n    y: [aggregate: :mean],\n    width: 700,\n    height: 400\n  )\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.size_by(\"precipitation\", type: :quantitative, scale: [range: [5, 350]])\n  |> Tucan.set_title(\"Daily Max Temperatures in Seattle 2012 - 2015\")\n  |> Tucan.Axes.set_y_title(\"Max Temperature\")\n  |> Tucan.Axes.set_x_title(\"Aggregated Months (2012-2015)\")\n  |> Tucan.Axes.put_options(:x, format: \"%b\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#aggregating-around-month","title":"Aggregating around month - Time Series Plots in Tucan","type":"extras"},{"doc":"We can use the `Tucan.facet_by/4` function to split the plot into small multiples. Let's split the above graph by `weather` in order to highlight weather-based temporal trends.\n\nYou can use various helper methods to modify things like the legend position or reset the dimensions of a plot or the axes titles.\n\n```elixir\naggregated_scatter\n|> Tucan.facet_by(:column, \"weather\")\n|> Tucan.set_size(130, 140)\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:size, \"bottom\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#faceting-the-plot","title":"Faceting the plot - Time Series Plots in Tucan","type":"extras"},{"doc":"We can use `Tucan`'s concat methods to combine plots vertically or horizontally. This is a form of view composition. We can combine plots horizontally with `Tucan.hconcat/2`, vertically with `Tucan.vconcat/2`, or via a general wrappable `Tucan.concat/2`.\n\nLet's combine both a bar-based frequency plot with this temporal plot.\n\n```elixir\nfrequencies =\n  Tucan.countplot(:weather, \"weather\", orient: :vertical, width: 700)\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.Axes.set_x_title(\"Num of Days with Weather (2012-2015)\")\n\nTucan.vconcat([aggregated_scatter, frequencies])\n```","ref":"time_series_plots_in_tucan.html#combining-two-plots-using-concatenation","title":"Combining two plots using concatenation - Time Series Plots in Tucan","type":"extras"},{"doc":"A strip plot is another way to explore variations in weather over time. In this case, let's encode the **date by month** along the _x-axis_, the **date by year** on the _y-axis_, and **weather** via color.\n\n```elixir\nstrip =\n  Tucan.stripplot(:weather, \"date\",\n    group: \"date\",\n    x: [time_unit: :monthdate, type: :temporal],\n    y: [time_unit: :year, type: :ordinal],\n    width: 700,\n    fill_opacity: 1\n  )\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.Axes.set_y_title(\"Year\")\n  |> Tucan.Axes.set_x_title(\"Month\")\n  |> Tucan.Axes.put_options(:x, format: \"%b\")\n```\n\nWe could add in a fourth dimension by encoding the **tick size** as a function of the **max_temp** field that day.\n\n```elixir\nstrip\n|> Tucan.size_by(\"temp_max\")\n|> Tucan.set_height(140)\n```\n\nYou could also change the `:mode` to `:jitter` to plot jittered points instead of ticks.\n\n```elixir\nTucan.stripplot(:weather, \"date\",\n  group: \"date\",\n  style: :jitter,\n  x: [time_unit: :monthdate, type: :temporal],\n  y: [time_unit: :year, type: :ordinal],\n  fill_opacity: 1\n)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.Axes.set_y_title(\"Year\")\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Axes.put_options(:x, format: \"%b\")\n|> Tucan.set_size(700, 300)\n```\n\n#","ref":"time_series_plots_in_tucan.html#stripplot","title":"Stripplot - Time Series Plots in Tucan","type":"extras"},{"doc":"Rather than encoding **year** on the `y-axis`, let's encode the **weather**.\n\n```elixir\nTucan.stripplot(:weather, \"date\",\n  group: \"weather\",\n  x: [time_unit: :monthdate, type: :temporal],\n  width: 700,\n  fill_opacity: 1\n)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.Axes.set_y_title(\"Weather\")\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Axes.put_options(:x, format: \"%b\")\n```","ref":"time_series_plots_in_tucan.html#strip-plot-split-by-weather","title":"Strip plot split by weather - Time Series Plots in Tucan","type":"extras"},{"doc":"A heatmap uses color to encode the magnitude of a value.\n\nLet's use a heatmap to examine how Seattle's max temperature changes over the year. For this, we will encode the **date by day** along the _x-axis_, the **date by month** along the _y-axis_, and the **average temp_max** as _color_.\n\n```elixir\nheatmap =\n  Tucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n    x: [time_unit: :date],\n    y: [time_unit: :month],\n    color: [aggregate: :mean]\n  )\n  |> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n  |> Tucan.Axes.set_x_title(\"Day\")\n  |> Tucan.Axes.set_y_title(\"Month\")\n  |> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#weather-heatmaps","title":"Weather heatmaps - Time Series Plots in Tucan","type":"extras"},{"doc":"Let's change the color scheme to something more semantic with **high** temperature values mapped to **red** and **low** temperature values mapped to **blue**. See the [Vega-Lite color scheme documentation](https://vega.github.io/vega/docs/schemes/) for more details on available schemes.\n\nThe only change to the previous plot is that we will change the `:color` encoding scheme. We can use the `Tucan.Scale.set_color_scheme/3` helper to easily set or change the color scheme of an existing plot. We  use the `reverse: true` option in order to make the **low** temperatures blue and the **high** temperatures red.\n\n```elixir\nTucan.Scale.set_color_scheme(heatmap, :redyellowblue, reverse: true)\n```\n\n#","ref":"time_series_plots_in_tucan.html#changing-the-heatmap-color-scheme","title":"Changing the heatmap color scheme - Time Series Plots in Tucan","type":"extras"},{"doc":"You can add annotations by setting the `:annotate` option to `true`. This will add a `:text` encoding to the plot which you can configure like all other encodings through the `:text` option.\n\n```elixir\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  annotate: true,\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  color: [aggregate: :mean],\n  text: [format: \".1f\"]\n)\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.set_width(800)\n```","ref":"time_series_plots_in_tucan.html#adding-in-heatmap-cells-the-labels","title":"Adding in heatmap cells the labels - Time Series Plots in Tucan","type":"extras"},{"doc":"Similar to the `heatmap` example, we can also make a `punchcard` to explore temporal Seattle weather patterns.\n\nWe'll use roughly the same encodings as before but this time map the average **temp_max** to circle **size**.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:size, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#punchcard-plots","title":"Punchcard Plots - Time Series Plots in Tucan","type":"extras"},{"doc":"We could also set a dual encoding where both **color** and **size** encode the average **temp_max** field. Notice that since this is a layered plot we also need to set `recursive: true` in the `Tucan.color_by/3` call.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:size, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#add-dual-encoding-of-temp-max","title":"Add dual encoding of temp max - Time Series Plots in Tucan","type":"extras"},{"doc":"Alternatively, we could encode **precipitation** as mark **size**.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#encode-precipitation-as-mark-size","title":"Encode precipitation as mark size - Time Series Plots in Tucan","type":"extras"},{"doc":"You can encode add both **temperature** and **precipitation** to the same punchcard plot by using both **color** and **size** encodings.\n\nWe are also using `Tucan.Legend.set_orientation/3` helper to change the position of the two legends.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, type: :quantitative, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"top\")\n|> Tucan.Legend.set_orientation(:size, \"top\")\n```","ref":"time_series_plots_in_tucan.html#encode-both-temperature-and-precipitation","title":"Encode both temperature and precipitation - Time Series Plots in Tucan","type":"extras"},{"doc":"While useful to graph the raw data above, aggregating our data along higher-order temporal dimensions like month or year might help highlight additional trends. Let's try graphing the average maximum temperature in Seattle by month from 2012-2015.\n\nWe can do this by combining Vega-Lite's `:time_unit` and `:aggregate` properties. We will specify that we want the _x-axis_ in **months** and to aggregate using the **mean**.\n\nWe will use `Tucan.lineplot/4` to plot the seasonal trend. By setting `points: true` we include the points to the line plot.\n\n```elixir\navg_temperature =\n  Tucan.lineplot(:weather, \"date\", \"temp_max\",\n    x: [time_unit: :month, type: :temporal],\n    y: [aggregate: :mean],\n    points: true,\n    tooltip: true,\n    width: 700\n  )\n  |> Tucan.set_title(\"Average Daily Max Temperatures in Seattle (2012-2015) by Month\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#lineplots-plotting-average-monthly-temperatures","title":"Lineplots - Plotting average monthly temperatures - Time Series Plots in Tucan","type":"extras"},{"doc":"We can add in an average line using `Tucan.hruler/3`. We can add a line either on a specific _y-axis_ point or on a calculated point.\n\n```elixir\nTucan.hruler(avg_temperature, \"temp_max\", line_color: \"red\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#adding-annotations-for-daily-max-average","title":"Adding annotations for daily max average - Time Series Plots in Tucan","type":"extras"},{"doc":"Similarly to all other plots we can use `color_by` to plot multiple lines for each **weather type**. Additionally we will use `stroke_dash_by` to make the plot more accessible.\n\n```elixir\nTucan.lineplot(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :month, type: :temporal],\n  y: [aggregate: :mean],\n  points: true,\n  tooltip: true\n)\n|> Tucan.color_by(\"weather\")\n|> Tucan.Scale.set_color_scheme(color_palette)\n|> Tucan.stroke_dash_by(\"weather\")\n|> Tucan.set_title(\"Average Daily Max Temperatures in Seattle (2012-2015) by Month & Weather\")\n|> Tucan.set_size(700, 350)\n```","ref":"time_series_plots_in_tucan.html#lines-by-weather-type","title":"Lines by weather type - Time Series Plots in Tucan","type":"extras"}]}